* This takes the combined air force data and runs the peer effects regressions in both...and asks whether the peer effects process has changed

* use the treat dummy to toggle between the two data sets 
* treat is either 0,1, or missing for the observayional data


clear all

capture log close

set logtype s

cd c:\w\data\fsort

log using Natural_Variation_to_Optimal_Policy, text replace 


set more off



use air_force_combined_new1


ren id resp_id
sort resp_id
merge resp_id using socialsurvey_resp
ren resp_id id
gen survey_respondent = _merge == 3



* create gpa_very_low measure for lowest 10 percent of gpa_hat
gen gpa_very_low=gpa_hat<2.372427

egen peer_num_bota=sum(gpa_bot), by(class_sqd_yr_sem)

egen peer_num_mida=sum(gpa_mid), by(class_sqd_yr_sem)

egen peer_num_topa=sum(gpa_top), by(class_sqd_yr_sem)

egen peer_gpa_hat=peers(gpa_hat), by(class_sqd_yr_sem)

egen peer_gpa_bot=peers(gpa_bot), by(class_sqd_yr_sem)
gen homogenous = 0
replace homogenous = 1 if treat==1 & peer_num_bot < 3

gen obs = 0
replace obs = 1 if clsyr < 2011

* need to recode peer percentages -1=0

recode peer_satv75 -1=0


* interact which sample with peer_satv75top etc

gen obser_satv75top=peer_satvtop75*obs
gen obser_satv75mid=peer_satvmid75*obs
gen obser_satv75bot=peer_satvbot75*obs

gen treat_satv75top=peer_satvtop75*(treat==1)
gen treat_satv75mid=peer_satvmid75*(treat==1)
gen treat_satv75bot=peer_satvbot75*(treat==1)

gen control_satv75top=peer_satvtop75*(treat==0)
gen control_satv75mid=peer_satvmid75*(treat==0)
gen control_satv75bot=peer_satvbot75*(treat==0)




gen obser_satv25top=peer_satvtop25*obs
gen obser_satv25mid=peer_satvmid25*obs
gen obser_satv25bot=peer_satvbot25*obs

gen treat_satv25top=peer_satvtop25*(treat==1)
gen treat_satv25mid=peer_satvmid25*(treat==1)
gen treat_satv25bot=peer_satvbot25*(treat==1)

gen control_satv25top=peer_satvtop25*(treat==0)
gen control_satv25mid=peer_satvmid25*(treat==0)
gen control_satv25bot=peer_satvbot25*(treat==0)


capture drop treat_top treat_mid treat_bot

gen treat_top=treat*gpa_top
gen treat_mid=treat*gpa_mid
gen treat_bot=treat*gpa_bot

* interact own gpa with top bot mid

gen obser_peer_gpa=peer_gpa*obs
gen treat_peer_gpa=peer_gpa*(treat==1)
gen control_peer_gpa=peer_gpa*(treat==0)


gen peer_gpatop=peer_gpa*gpa_top
gen peer_gpamid=peer_gpa*gpa_mid
gen peer_gpabot=peer_gpa*gpa_bot


gen obser_peer_gpatop=peer_gpatop*obs
gen obser_peer_gpamid=peer_gpamid*obs
gen obser_peer_gpabot=peer_gpabot*obs

gen treat_peer_gpatop=peer_gpatop*(treat==1)
gen treat_peer_gpamid=peer_gpamid*(treat==1)
gen treat_peer_gpabot=peer_gpabot*(treat==1)

gen control_peer_gpatop=peer_gpatop*(treat==0)
gen control_peer_gpamid=peer_gpamid*(treat==0)
gen control_peer_gpabot=peer_gpabot*(treat==0)

gen control=treat==0

gen peer_num_bottop=peer_num_bot*gpa_top
gen peer_num_botmid=peer_num_bot*gpa_mid
gen peer_num_botbot=peer_num_bot*gpa_bot


* interact gpa_top and gpa_mid status with whether or not I am a high verbal SAT guy

gen gpa_top_highV=gpa_top*satv75
gen gpa_top_lowV= gpa_top*(satv75==0)

gen gpa_mid_highV=gpa_mid*satv75
gen gpa_mid_lowV= gpa_mid*(satv75==0)


gen treat_top_highV=treat*gpa_top*satv75
gen treat_top_lowV= treat*gpa_top*(satv75==0)

gen treat_mid_highV=treat*gpa_mid*satv75
gen treat_mid_lowV=treat*gpa_mid*(satv75==0)

gen satv50=0 
replace satv50=1 if satv75==0 & satv25==0
egen satv50_sum=sum(satv50), by(class_sqd_yr_sem) 



gen num_highSATV="0 to 5" if satv75_sum<=5
replace num_highSATV="6 to 12" if satv75_sum<=12 & satv75_sum>=6
replace num_highSATV=">12" if satv75_sum>=13

gen num_lowSATV="0 to 5" if satv25_sum<=5
replace num_lowSATV="6 to 12" if satv25_sum<=12 & satv75_sum>=6
replace num_lowSATV=">12" if satv25_sum>=13

* the middle group here is the 90-10 range in the control group
gen num_lowGPAhat="0 to 6" if peer_num_bot<=6
replace num_lowGPAhat="7 to 14" if peer_num_bot<=14 & peer_num_bot>=7
replace num_lowGPAhat=">14" if peer_num_bot>=15


* identify the first observation of each squad and class year                      

sort class_sqd id
gen first_ob=1 if _n==1
replace first_ob=1 if class_sqd!=class_sqd[_n-1] & class_sqd!=. & class_sqd[_n-1]!=.

egen class_sqd_yr=group(clsyr squadron)

label var treat "Treatment Group"
label var control "Control Group"
label var gpa "Grade Point Average"
label var peer_satv75 "Fraction of High SAT-V Peers"
label var peer_satm75 "Fraction of High SAT-M Peers"
label var peer_aca75 "Fraction of High Ac Comp Peers"

label var peer_satv25 "Fraction of Low SAT-V Peers"
label var peer_satm25 "Fraction of Low SAT-M Peers"
label var peer_aca25 "Fraction of Low Ac Comp Peers"


label var sat_m "SAT-Math Score"
label var sat_v "SAT-Verbal Score"

label var aca_cmp "HS Academic Composite"
label var cft_score "HS Fitness Score"
label var leadership_cmp "HS Leadership Score"
label var rathlete "Recruited Athlete"
label var pschool "Attended Prep School"
label var black "Student is Black"
label var hispanic "Student is Hispanic"
label var asian "Student is Asian"
label var female "Student is Female"
label var gpa_bot "$\widehat{GPA}$ in Lowest Third of Class"
label var gpa_mid "$\widehat{GPA}$ in Middle Third of Class"
label var gpa_top "$\widehat{GPA}$ in Highest Third of Class"
label var ACA "Academic Composite Using SATs Plus High School GPA"
label var treat "Student in Treatment Group"
label var control "Student in Control Group"
label var obs "Observational (Pre-Experimental) Group"

label var peer_satvtop75 "Fraction of High SAT-V Peers $\times$ High $\widehat{GPA}$"
label var peer_satvmid75 "Fraction of High SAT-V Peers $\times$ Middle $\widehat{GPA}$"
label var peer_satvbot75 "Fraction of High SAT-V Peers $\times$ Low $\widehat{GPA}$"


label var peer_satmtop75 "Fraction of High SAT-M Peers $\times$ High $\widehat{GPA}$"
label var peer_satmmid75 "Fraction of High SAT-M Peers $\times$ Middle $\widehat{GPA}$"
label var peer_satmbot75 "Fraction of High SAT-M Peers $\times$ Low $\widehat{GPA}$"

label var peer_acatop75 "Fraction of High Ac Comp Peers $\times$ High $\widehat{GPA}$"
label var peer_acamid75 "Fraction of High Ac Comp Peers $\times$ Middle $\widehat{GPA}$"
label var peer_acabot75 "Fraction of High Ac Comp Peers $\times$ Low $\widehat{GPA}$"


label var peer_satvtop25 "Fraction of Low SAT-V Peers $\times$ High $\widehat{GPA}$"
label var peer_satvmid25 "Fraction of Low SAT-V Peers $\times$ Middle $\widehat{GPA}$"
label var peer_satvbot25 "Fraction of Low SAT-V Peers $\times$ Low $\widehat{GPA}$"

label var peer_satmtop25 "Fraction of Low SAT-M  Peers $\times$ High $\widehat{GPA}$"
label var peer_satmmid25 "Fraction of Low SAT-M  Peers $\times$ Middle $\widehat{GPA}$"
label var peer_satmbot25 "Fraction of Low SAT-M  Peers $\times$ Low $\widehat{GPA}$"


label var peer_acatop25 "Fraction of Low Ac Comp  Peers $\times$ High $\widehat{GPA}$"
label var peer_acamid25 "Fraction of Low Ac Comp  Peers $\times$ Middle $\widehat{GPA}$"
label var peer_acabot25 "Fraction of Low Ac Comp  Peers $\times$ Low $\widehat{GPA}$"






label var obser_satv75top "Obs. Group $\times$ Fraction High SAT-V Peers$\times$ High $\widehat{GPA}$ "
label var obser_satv75mid "Obs. Group $\times$ Fraction High SAT-V Peers$\times$ Middle $\widehat{GPA}$ "
label var obser_satv75bot "Obs. Group $\times$ Fraction High SAT-V Peers$\times$ Low $\widehat{GPA}$ "

label var control_satv75top "Control Group $\times$ Fraction High SAT-V Peers$\times$ High $\widehat{GPA}$ "
label var control_satv75mid "Control Group $\times$ Fraction High SAT-V Peers$\times$ Middle $\widehat{GPA}$ "
label var control_satv75bot "Control Group $\times$ Fraction High SAT-V Peers$\times$ Low $\widehat{GPA}$ "


label var obser_satv25top "Obs. Group $\times$ Fraction Low SAT-V Peers$\times$ High $\widehat{GPA}$ "
label var obser_satv25mid "Obs. Group $\times$ Fraction Low SAT-V Peers$\times$ Middle $\widehat{GPA}$ "
label var obser_satv25bot "Obs. Group $\times$ Fraction Low SAT-V Peers$\times$ Low $\widehat{GPA}$ "

label var control_satv25top "Control Group $\times$ Fraction Low SAT-V Peers$\times$ High $\widehat{GPA}$ "
label var control_satv25mid "Control Group $\times$ Fraction Low SAT-V Peers$\times$ Middle $\widehat{GPA}$ "
label var control_satv25bot "Control Group $\times$ Fraction Low SAT-V Peers$\times$ Low $\widehat{GPA}$ "









label var peer_gpa "Peers' GPA"
label var obser_peer_gpa "Obs. Group $\times$ Peers' GPA"
label var control_peer_gpa "Control Group $\times$ Peers' GPA"


label var peer_gpatop "Peers' GPA $\times$ High $\widehat{GPA}$"
label var peer_gpamid "Peers' GPA $\times$ Middle $\widehat{GPA}$"
label var peer_gpabot "Peers' GPA $\times$ Low $\widehat{GPA}$"



label var obser_peer_gpatop "Obs Group $\times$ Peers' GPA $\times$ High $\widehat{GPA}$"
label var obser_peer_gpamid "Obs Group $\times$ Peers' GPA $\times$ Middle $\widehat{GPA}$"
label var obser_peer_gpabot "Obs Group $\times$ Peers' GPA $\times$ Low $\widehat{GPA}$"


label var control_peer_gpatop "Control Group $\times$ Peers' GPA $\times$ High $\widehat{GPA}$"
label var control_peer_gpamid "Control Group $\times$ Peers' GPA $\times$ Middle $\widehat{GPA}$"
label var control_peer_gpabot "Control Group $\times$ Peers' GPA $\times$ Low $\widehat{GPA}$"


label var peer_num_bot "Number of Peers in Low $\widehat{GPA}$"
label var peer_num_bottop "Num Peers Low $\widehat{GPA}$ $\times$ Self in High $\widehat{GPA}$"
label var peer_num_botmid "Num Peers Low $\widehat{GPA}$ $\times$ Self in Middle $\widehat{GPA}$"
label var peer_num_botbot "Num Peers Low $\widehat{GPA}$ $\times$ Self in Low $\widehat{GPA}$"


* label var bifurcated "Squadron Has >=16 Bottom Students and >=12 Top Students"
label var treat_top "Treatment Group $\times$ High $\widehat{GPA}$"
label var treat_mid "Treatment Group $\times$ Middle $\widehat{GPA}$"
label var treat_bot "Treatment Group $\times$ Low $\widehat{GPA}$"

label var gpa "Grade Point Average"

xi i.clsyr i.semester

label var  _Iclsyr_2006 "Class=2006"
label var  _Iclsyr_2007 "Class=2007"
label var  _Iclsyr_2008 "Class=2008"
label var  _Iclsyr_2009 "Class=2009"
label var  _Iclsyr_2010 "Class=2010"
label var  _Iclsyr_2011 "Class=2011"
label var  _Iclsyr_2012 "Class=2012"
label var  _Isemester_2 "Semester=Spring"


* create attrition variable defined in first semester for attriting in either semester
gen gpa_second_semesterA=gpa if semester==2
egen gpa_second_semester=max(gpa_second_semesterA), by(id)
drop gpa_second_semesterA

gen attrit1=0 if semester==1
replace attrit1=1 if semester==1 & gpa==.

gen attrit2=0 if semester==2
replace attrit2=1 if semester==2 & gpa==.

gen attrit_ever=0
replace attrit_ever=1 if gpa==. | gpa_second_semester==.



*************************************************************
* take a look at the survey data *****
* are bottom kids in treatment group more likely to have bottom study partners versus other bottom kids? ****


* count up the number of high, low gpa study partners freshman year

egen low_gpa_study_partners=rsum( s41_gpa_bot s42_gpa_bot s43_gpa_bot s44_gpa_bot s45_gpa_bot)

egen high_gpa_study_partners=rsum( s41_gpa_top s42_gpa_top s43_gpa_top s44_gpa_top s45_gpa_top)

egen mid_gpa_study_partners=rsum( s41_gpa_mid s42_gpa_mid s43_gpa_mid s44_gpa_mid s45_gpa_mid)

egen low_gpa_friends=rsum( f41_gpa_bot f42_gpa_bot f43_gpa_bot f44_gpa_bot f45_gpa_bot)
egen mid_gpa_friends=rsum( f41_gpa_mid f42_gpa_mid f43_gpa_mid f44_gpa_mid f45_gpa_mid)
egen high_gpa_friends=rsum( f41_gpa_top f42_gpa_top f43_gpa_top f44_gpa_top f45_gpa_top)




egen summ_gpa_hat_study_partners=rsum( s41_gpa_hat s42_gpa_hat s43_gpa_hat s44_gpa_hat s45_gpa_hat)


egen num_friends=rownonmiss( f41_gpa_bot f42_gpa_bot f43_gpa_bot f44_gpa_bot f45_gpa_bot)

recode num_friends 0=. 


egen num_study=rownonmiss( s41_gpa_bot s42_gpa_bot s43_gpa_bot s44_gpa_bot s45_gpa_bot)


recode num_study 0=. 

gen fraction_friends_low_gpa=low_gpa_friends/num_friends
gen fraction_friends_mid_gpa=mid_gpa_friends/num_friends
gen fraction_friends_high_gpa=high_gpa_friends/num_friends
* gen fraction_friends_high_gpa=high_gpa_friends/num_friends
gen fraction_study_low_gpa=low_gpa_study_partners/num_study


gen fraction_study_low_gpa_50=0 if s41_gpa_bot~=.
replace fraction_study_low_gpa_50 =1 if fraction_study_low_gpa >=.5
replace fraction_study_low_gpa_50=. if fraction_study_low_gpa==.

gen fraction_friends_low_gpa_50=0 if f41_gpa_bot~=.
replace fraction_friends_low_gpa_50 =1 if fraction_friends_low_gpa >=.5
replace fraction_friends_low_gpa_50=. if fraction_friends_low_gpa==.


gen fraction_study_high_gpa=high_gpa_study_partners/num_study

gen fraction_study_mid_gpa=mid_gpa_study_partners/num_study

gen mean_gpa_hat_study_partners=summ_gpa_hat_study_partners/num_study


* count up number high satV study partners
egen high_satV_study_partners=rsum( s41_satv75 s42_satv75 s43_satv75 s44_satv75 s45_satv75) 

gen fraction_high_satv_study=high_satV_study_partners/num_study

egen high_satV_friends=rsum( f41_satv75 f42_satv75 f43_satv75 f44_satv75 f45_satv75) 

gen fraction_high_satv_friends=high_satV_friends/num_friends

* count up number black and female friends and study partners
egen black_study_partners=rsum( s41_black s42_black s43_black s44_black s45_black) 

egen black_friends=rsum( f41_black f42_black f43_black f44_black f45_black) 

egen female_study_partners=rsum( s41_female s42_female s43_female s44_female s45_female) 

egen female_friends=rsum( f41_female f42_female f43_female f44_female f45_female) 


***************************************************************
* Run the check of randomization...Table 3 *
***************************************************************

replace sat_m=sat_m/100
replace sat_v=sat_v/100
label var _Iclsyr_2011  "Class of 2011"

*Table 3, test that the split into treatment and control was random
xi: reg treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr  if treat~=. & clsyr==2011 & semester==1
test sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female 
local F1 = r(F)
local P1 = r(p)
outreg2 using table3.tex, nocons nonotes replace se 10pct tdec(3) bd(3) label ct("Class 2011") addstat(F All Variables, `F1', p-value, `P1')



xi: reg treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr  if treat~=. & clsyr==2012. & semester==1
test sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female 
local F1 = r(F)
local P1 = r(p)
outreg2 using table3.tex, nocons nonotes append se 10pct tdec(3) bd(3) label ct("Class 2012") addstat(F All Variables, `F1', p-value, `P1')

xi: reg treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr  if treat~=.  & semester==1
test sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female 
local F1 = r(F)
local P1 = r(p)
outreg2 using table3.tex, nocons nonotes tex(frag pretty) append se 10pct tdec(3) bd(3) label ct("All Classes") addstat(F All Variables, `F1', p-value, `P1')

********************************************************
* 10.21.11 respond to referees and try some new ideas
********************************************************

* in study partners stuff, limit sample to guys who provided at least one study partner/ friend
* restructure these to include treat_middle we can read treat_bot effect directly



* do anything with sophomore year friends? 

* try effects separately by race and gender..both main results and study partners
* I actually include race and gender interactions since not enough data to run separately by race

gen black_treat_bot=black*treat_bot
gen female_treat_bot=female*treat_bot
gen rathlete_treat_bot=rathlete*treat_bot
gen pschool_treat_bot=pschool*treat_bot
gen treat_black=black*treat
gen treat_female=female*treat
gen treat_rathlete=rathlete*treat
gen treat_pschool=pschool*treat

label var black_treat_bot "Black $\times$ Treatment $\times$ Low $\widehat{GPA}$"
label var female_treat_bot "Female $\times$ Treatment $\times$ Low $\widehat{GPA}$"
label var rathlete_treat_bot "Athlete $\times$ Treatment $\times$ Low $\widehat{GPA}$"
label var pschool_treat_bot "Prep School $\times$ Treatment $\times$ Low $\widehat{GPA}$"

gen black_bot=black*gpa_bot
gen female_bot=female*gpa_bot
gen rathlete_bot=rathlete*gpa_bot
gen pschool_bot=pschool*gpa_bot

label var black_bot "Black $\times$ Low $\widehat{GPA}$"
label var female_bot "Female $\times$ Low $\widehat{GPA}$"
label var rathlete_bot "Athlete $\times$ Low $\widehat{GPA}$"
label var pschool_bot "Prep School $\times$ Low $\widehat{GPA}$"

gen black_treat_mid=black*treat_mid
gen female_treat_mid=female*treat_mid
gen rathlete_treat_mid=rathlete*treat_mid
gen pschool_treat_mid=pschool*treat_mid
gen black_treat_top=black*treat_top
gen female_treat_top=female*treat_top
gen rathlete_treat_top=rathlete*treat_top
gen pschool_treat_top=pschool*treat_top

label var treat_black "Black $\times$ Treatment"
label var treat_female "Female $\times$ Treatment"
label var treat_rathlete "Athlete $\times$ Treatment"
label var treat_pschool "Prep School $\times$ Treatment"

label var black_treat_mid "Black $\times$ Treatment $\times$ Mid $\widehat{GPA}$"
label var female_treat_mid "Female $\times$ Treatment $\times$ Mid $\widehat{GPA}$"
label var rathlete_treat_mid "Athlete $\times$ Treatment $\times$ Mid $\widehat{GPA}$"
label var pschool_treat_mid "Prep School $\times$ Treatment $\times$ Mid $\widehat{GPA}$"
label var black_treat_top "Black $\times$ Treatment $\times$ High $\widehat{GPA}$"
label var female_treat_top "Female $\times$ Treatment $\times$ High $\widehat{GPA}$"
label var rathlete_treat_top "Athlete $\times$ Treatment $\times$ High $\widehat{GPA}$"
label var pschool_treat_top "Prep School $\times$ Treatment $\times$ High $\widehat{GPA}$"

label var low_gpa_study "Number Low $\widehat{GPA}$ Study Partners"
label var low_gpa_friends "Number Low $\widehat{GPA}$ Friends"
label var high_gpa_study "Number High $\widehat{GPA}$ Study Partners"
label var mid_gpa_study "Number Mid $\widehat{GPA}$ Study Partners"
label var peer_gpa_bot "Fraction Low $\widehat{GPA}$ Squadron Peers"
egen peer_gpa_top=peers(gpa_top), by(class_sqd_yr_sem)
label var peer_gpa_top "Fraction High $\widehat{GPA}$ Squadron Peers"
label var peer_gpa_hat "Average $\widehat{GPA}$ of Squadron Peers"


*************************************************************************************************************************************************************  Re-run the study partners and friends regressions using fraction instead of absolute number ************************
****************************************************************************


xi: reg fraction_study_low_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes replace tdec(3) bdec(3) se 10pct ctitle("Fraction", "Low $\widehat{GPA}$", "Study", "Partners")  label
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Low $\widehat{GPA}$", "Study", "Partners")  label

xi: reg fraction_study_mid_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Middle $\widehat{GPA}$", "Study", "Partners")  label
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Middle $\widehat{GPA}$", "Study", "Partners")  label

xi: reg fraction_study_high_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "High $\widehat{GPA}$", "Study", "Partners")  label
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "High $\widehat{GPA}$", "Study", "Partners")  label

xi: reg fraction_high_satv_study treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes  append tdec(3) bdec(3) se 10pct ctitle("Fraction", "High SAT-V", "Study", "Partners") label
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes  append tdec(3) bdec(3) se 10pct ctitle("Fraction", "High SAT-V", "Study", "Partners") label


xi: reg fraction_study_low_gpa_50 treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes  append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Low $\widehat{GPA}$", "Study Partners", "$> 0.50$") label
outreg2 treat_bot treat_mid treat_top using study_partners_table_fraction.tex, nocons nonotes tex(frag pretty)   append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Low $\widehat{GPA}$", "Study Partners", "$> 0.50$") label






xi: reg fraction_friends_low_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes replace tdec(3) bdec(3) se 10pct ctitle("Fraction", "Low $\widehat{GPA}$", "Friends") label
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Low $\widehat{GPA}$", "Friends") label

xi: reg fraction_friends_mid_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Middle $\widehat{GPA}$", "Friends") label
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Middle $\widehat{GPA}$", "Friends") label

xi: reg fraction_friends_high_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "High $\widehat{GPA}$", "Friends") label
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "High $\widehat{GPA}$", "Friends") label

xi: reg fraction_high_satv_friends treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "High SAT-V", "Friends") label
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes append tdec(3) bdec(3) se 10pct ctitle("Fraction", "High SAT-V", "Friends") label

xi: reg fraction_friends_low_gpa_50 treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes  append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Low $\widehat{GPA}$", "Friends", "$> 0.50$") label
outreg2 treat_bot treat_mid treat_top using friends_table_fraction.tex, nocons nonotes tex(frag pretty) append tdec(3) bdec(3) se 10pct ctitle("Fraction", "Low $\widehat{GPA}$", "Friends", "$> 0.50$") label


xi: reg  treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 & s41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using study_partners_table_new.tex, nocons nonotes replace tdec(3) bdec(3)  se 10pct label ctitle("Number", "Low $\widehat{GPA}$", "Study", "Partners")

* add interactions for treatment, bottom, female..discuss the other results in the text
xi: reg low_gpa_study treat_bot black_treat_bot black_bot treat_black treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 & s41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot black_treat_bot black_bot treat_black treat_mid treat_top using study_partners_table_new.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Number", "Low $\widehat{GPA}$", "Study", "Partners") 


xi: reg high_gpa_study treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1  & s41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using study_partners_table_new.tex, nocons nonotes append tdec(3) bdec(3)  se  10pct label ctitle("Number", "High $\widehat{GPA}$", "Study", "Partners") 


xi: reg mid_gpa_study treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1  & s41_id!=., robust cluster(class_sqd_yr) 
outreg2 treat_bot treat_mid treat_top using study_partners_table_new.tex, nocons nonotes append tdec(3) bdec(3)  se  10pct label ctitle("Number", "Mid $\widehat{GPA}$", "Study", "Partners") 


xi: reg low_gpa_friends treat_bot black_treat_bot black_bot treat_black treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1  & f41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot black_treat_bot black_bot treat_black treat_mid treat_top using study_partners_table_new.tex, nocons nonotes append tdec(3) bdec(3)  se  10pct label ctitle("Number", "Low $\widehat{GPA}$", "Friends") 




xi: reg high_satV_study_partners treat_bot treat_mid treat_top resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1  & s41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top resp_gpa_bot using study_partners_table_new.tex, nocons nonotes append  tdec(3) bdec(3)  se 10pct label ctitle("Number", "High SAT-V", "Study", "Partners") 


xi: reg high_satV_friends treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1  & f41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top resp_gpa_bot using study_partners_table_new.tex, nocons nonotes tex(frag pretty) append bdec(3) tdec(3) se 10pct label ctitle("Number", "High SAT-V", "Friends") 



* create a table showing how study partners and friends cluster by race more in the treatment group
xi: reg black_study treat_bot black_treat_bot black_bot treat_black treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 & s41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot black_treat_bot black_bot treat_black treat_mid treat_top black using black_study_partners_table_new.tex, nocons nonotes replace bdec(3) tdec(3) se 10pct label word ctitle("Number", "Black", "Study", "Partners")


xi: reg black_friends treat_bot black_treat_bot black_bot treat_black treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 & f41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot black_treat_bot black_bot treat_black treat_mid treat_top black using black_study_partners_table_new.tex, nocons nonotes append bdec(3) tdec(3) se 10pct label word ctitle("Number", "Black", "Friends")



xi: reg female_study treat_bot female_treat_bot female_bot treat_female treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 & s41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot female_treat_bot female_bot treat_female treat_mid treat_top female using black_study_partners_table_new.tex, nocons nonotes append bdec(3) tdec(3) se 10pct label word ctitle("Number", "Female", "Study", "Partners")



xi: reg female_friends treat_bot female_treat_bot female_bot treat_female treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 & f41_id!=., robust cluster(class_sqd_yr)
outreg2 treat_bot female_treat_bot female_bot treat_female treat_mid treat_top female using black_study_partners_table_new.tex, nocons nonotes tex(frag pretty) append bdec(3) tdec(3) se 10pct label word ctitle("Number", "Female", "Friends")



*****************************************************************************
*****************************************************************************

* have a table that shows Table 2 but strictly in the Control group 
* (not the observational)

* control
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
test peer_satvtop75=peer_satvmid75 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot75=peer_satvmid75 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 using baseline_nonlinear_incontrol.tex, nocons nonotes replace se tdec(3) label cttop("SAT-V Peer Variables") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')


* control
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
test peer_satvtop75=peer_satvmid75 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot75=peer_satvmid75 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 using baseline_nonlinear_incontrol.tex, nocons nonotes tex(frag pretty) append se tdec(3)  label cttop("All Peer Variables") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')




*****************************************************************************
*****************************************************************************

* referee comment: look at squadron heterogeneity in observational and interact with own status
 * bruce: switch to gpa_hat from satV

egen squadron_hetero=sd(gpa_hat), by(class_sqd_yr)

gen squadron_hetero_squared= squadron_hetero*squadron_hetero

gen squadron_hetero_top=gpa_top*squadron_hetero
gen squadron_hetero_mid=gpa_mid*squadron_hetero
gen squadron_hetero_bot=gpa_bot*squadron_hetero

gen squadron_hetero_top_sq= squadron_hetero_top^2
gen squadron_hetero_mid_sq= squadron_hetero_mid^2
gen squadron_hetero_bot_sq= squadron_hetero_bot^2

gen hetero_peer_satv75=squadron_hetero*peer_satv75
gen hetero_peer_satv75_sq=squadron_hetero_squared*peer_satv75

label var squadron_hetero "Peer Group SD$(\widehat{GPA})$"
label var squadron_hetero_sq "Peer Group VAR$(\widehat{GPA})$"
label var hetero_peer_satv75 "Peer Heteroegenity $\times$ Fraction of High SAT-V Peers"
label var hetero_peer_satv75_sq "Peer Heteroegenity$^2$ $\times$ Fraction of High SAT-V Peers"

label var peer_satv75 "Fraction High SAT-V Peers"

* run the polynomial separate for high and low cadets rather than trying to get all cadets into a fully interacted model

xi: reg gpa peer_satv75 squadron_hetero squadron_hetero_squared hetero_peer_satv75 hetero_peer_satv75_sq sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_bot==1, robust cluster(class_sqd_yr)
outreg2 peer_satv75 squadron_hetero squadron_hetero_squared hetero_peer_satv75 hetero_peer_satv75_sq using hetero_interaction_table2.tex, nocons nonotes replace bdec(3) tdec(3) se label ctitle("Low $\widehat{GPA}$") 

xi: reg gpa peer_satv75 squadron_hetero squadron_hetero_squared hetero_peer_satv75 hetero_peer_satv75_sq sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_mid==1, robust cluster(class_sqd_yr)
outreg2 peer_satv75 squadron_hetero squadron_hetero_squared hetero_peer_satv75 hetero_peer_satv75_sq using hetero_interaction_table2.tex, nocons nonotes append  bdec(3) tdec(3) se label ctitle("Middle $\widehat{GPA}$") 

xi: reg gpa peer_satv75 squadron_hetero squadron_hetero_squared hetero_peer_satv75 hetero_peer_satv75_sq sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_top==1, robust cluster(class_sqd_yr)
outreg2 peer_satv75 squadron_hetero squadron_hetero_squared hetero_peer_satv75 hetero_peer_satv75_sq using hetero_interaction_table2.tex, nocons nonotes tex(frag pretty) append  bdec(3) tdec(3) se label ctitle("High $\widehat{GPA}$")



*****************************************************************************
*****************************************************************************

* referee 2 comment 4: run the fully interacted model (Table 6) on the control sample..its a bit like Daron's comment of showing that the old model still works but this is with all possible peer measures
* turns out peer effects even stronger in control group in the fully interacted

* Control group
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25

local F1 = r(F)
local P1 = r(p)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F2 = r(F)
local P2 = r(p)

test peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_satmtop25 peer_satmmid25 peer_satmbot25
local F3 = r(F)
local P3 = r(p)

outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 using checkpeereffects_nonlinear_combinedmodel.tex, nocons nonotes replace se tdec(3) label cttop("Obs. Group ") addstat(F All Peer Variables, `F1', p-value, `P1', F Peer SAT Verbal, `F2', p-value, `P2', F Peer SAT Math, `F3', p-value, `P3')


*****************************************************************************
*****************************************************************************

* referee 5 comment 3: Table 4 (predicted treatment effects)...show standard errors not standard deviations of predicted effects

* start by running our baseline table 2 regression
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. /*, robust cluster(class_sqd_yr) */

* then predict into the treatment and control samples
predict gpa_hat2
predict gpa_hat_se, stdf
gen gpa_hat_var = gpa_hat_se^2
egen treat_atype = group(treat gpa_top gpa_mid gpa_bot)
sort treat_atype
by treat_atype: egen m_gpa_hat_v = mean(gpa_hat_var) 
by treat_atype: egen group_count = count(gpa_hat_var)
gen m_gpa_hat_var = m_gpa_hat_v/group_count + 40*33*32*0.085^2/1223^2


* get means and standard errors of prediction

reg gpa_hat2 treat control if treat!=. & semester==1 , nocons
ttest gpa_hat2 if e(sample) , by(treat)
local D1 = -r(t)*r(se)
sum m_gpa_hat_var if treat==1 
scalar t_var = r(mean) 
display "Treatment SD =  " t_var^0.5
sum m_gpa_hat_var if treat==0 
scalar c_var = r(mean) 
display "Control SD =  "c_var^0.5
local SE1 = (t_var+c_var)^0.5
display "SD of Difference =" `SE1'
outreg2 using newtable4.tex, tdec(3) se label nonotes noaster replace addstat(Predicted Treatment Effect, `D1', SE of Predicted Difference, `SE1') ctitle("All", "Students") 



reg gpa_hat2 treat control if treat!=. & gpa_bot==1 & semester==1, nocons
ttest gpa_hat2 if e(sample) , by(treat)
local D1 = -r(t)*r(se)
sum m_gpa_hat_var if treat==1 & gpa_bot==1
scalar t_var = r(mean)
display "Treatment SD =  " t_var^0.5
sum m_gpa_hat_var if treat==0 & gpa_bot==1
scalar c_var = r(mean)
display "Control SD =  "c_var^0.5
local SE1 = (t_var+c_var)^0.5
display "SD of Difference =" `SE1'
outreg2 using newtable4.tex, tdec(3) se label noaster nonotes append addstat(Predicted Treatment Effect, `D1', SE of Predicted Difference, `SE1') ctitle("Bottom", "$\widehat{GPA}$") 


reg gpa_hat2 treat control if treat!=. & gpa_mid==1 & semester==1, nocons
ttest gpa_hat2 if e(sample) , by(treat)
local D1 = -r(t)*r(se)
sum m_gpa_hat_var if treat==1 & gpa_mid==1
scalar t_var = r(mean)
display "Treatment SD =  " t_var^0.5
sum m_gpa_hat_var if treat==0 & gpa_mid==1
scalar c_var = r(mean)
display "Control SD =  "c_var^0.5
local SE1 = (t_var+c_var)^0.5
display "SD of Difference =" `SE1'
outreg2 using newtable4.tex, tdec(3) se label noaster nonotes append addstat(Predicted Treatment Effect, `D1', SE of Predicted Difference, `SE1') ctitle("Middle", "$\widehat{GPA}$") 



reg gpa_hat2 treat control if treat!=. & gpa_top==1 & semester==1, nocons
ttest gpa_hat2 if e(sample) , by(treat)
local D1 = -r(t)*r(se)
sum m_gpa_hat_var if treat==1 & gpa_top==1
scalar t_var = r(mean)
display "Treatment SD =  " t_var^0.5
sum m_gpa_hat_var if treat==0 & gpa_top==1
scalar c_var = r(mean)
display "Control SD =  "c_var^0.5
local SE1 = (t_var+c_var)^0.5
display "SD of Difference =" `SE1'
outreg2 using newtable4.tex, tex(frag pretty) tdec(3) nonotes se label noaster append addstat(Predicted Treatment Effect, `D1', SE of Predicted Difference, `SE1') ctitle("Top", "$\widehat{GPA}$") 


*****************************************************************************
*****************************************************************************

* referee 5 comment 1: use tertiles in estimation rather than quartiles

* start by calculating tertiles
egen sat_v_66pctile=pctile(sat_v), p(66) by(clsyr) 
 egen sat_v_33pctile=pctile(sat_v), p(33) by(clsyr) 
 gen sat_v66=0 
replace sat_v66=1 if sat_v>=sat_v_66pctile 
 gen sat_v33=0 
replace sat_v33=1 if sat_v<sat_v_33pctile 
 egen sat_v_size=count(sat_v), by(class_sqd_yr_sem) 
 egen sat_v66_sum=sum(sat_v66), by(class_sqd_yr_sem) 
 egen sat_v33_sum=sum(sat_v33), by(class_sqd_yr_sem) 
 gen peer_satv66= (sat_v66_sum-sat_v66)/(sat_v_size-1) 
 gen peer_satv33= (sat_v33_sum-sat_v33)/(sat_v_size-1) 
 gen peer_satvtop33=peer_satv33*gpa_top 
gen peer_satvmid33=peer_satv33*gpa_mid 
gen peer_satvbot33=peer_satv33*gpa_bot 
 gen peer_satvtop66=peer_satv66*gpa_top 
gen peer_satvmid66=peer_satv66*gpa_mid 
gen peer_satvbot66=peer_satv66*gpa_bot 


egen sat_m_66pctile=pctile(sat_m), p(66) by(clsyr) 
 egen sat_m_33pctile=pctile(sat_m), p(33) by(clsyr) 
 gen sat_m66=0 
replace sat_m66=1 if sat_m>=sat_m_66pctile 
 gen sat_m33=0 
replace sat_m33=1 if sat_m<sat_m_33pctile 
 egen sat_m_size=count(sat_m), by(class_sqd_yr_sem) 
 egen sat_m66_sum=sum(sat_m66), by(class_sqd_yr_sem) 
 egen sat_m33_sum=sum(sat_m33), by(class_sqd_yr_sem) 
 gen peer_satm66= (sat_m66_sum-sat_m66)/(sat_m_size-1) 
 gen peer_satm33= (sat_m33_sum-sat_m33)/(sat_m_size-1) 
 gen peer_satmtop33=peer_satm33*gpa_top 
gen peer_satmmid33=peer_satm33*gpa_mid 
gen peer_satmbot33=peer_satm33*gpa_bot 
 gen peer_satmtop66=peer_satm66*gpa_top 
gen peer_satmmid66=peer_satm66*gpa_mid 
gen peer_satmbot66=peer_satm66*gpa_bot 



egen aca_66pctile=pctile(aca_cmp), p(66) by(clsyr) 
 egen aca_33pctile=pctile(aca_cmp), p(33) by(clsyr) 
 gen aca66=0 
replace aca66=1 if aca_cmp>=aca_66pctile 
 gen aca33=0 
replace aca33=1 if aca_cmp<aca_33pctile 
capture drop aca_size 
egen aca_size=count(aca_cmp), by(class_sqd_yr_sem) 
 egen aca66_sum=sum(aca66), by(class_sqd_yr_sem) 
 egen aca33_sum=sum(aca33), by(class_sqd_yr_sem) 
 gen peer_aca66= (aca66_sum-aca66)/(aca_size-1) 
 gen peer_aca33= (aca33_sum-aca33)/(aca_size-1) 
 gen peer_acatop33=peer_aca33*gpa_top 
gen peer_acamid33=peer_aca33*gpa_mid 
gen peer_acabot33=peer_aca33*gpa_bot 
 gen peer_acatop66=peer_aca66*gpa_top 
gen peer_acamid66=peer_aca66*gpa_mid 
gen peer_acabot66=peer_aca66*gpa_bot 

egen cft_66pctile=pctile(cft_score), p(66) by(clsyr) 
 egen cft_33pctile=pctile(cft_score), p(33) by(clsyr) 
 gen cft66=0 
replace cft66=1 if cft_score>=cft_66pctile 
 gen cft33=0 
replace cft33=1 if cft_score<cft_33pctile 
capture drop cft_size 
egen cft_size=count(cft_score), by(class_sqd_yr_sem) 
 egen cft66_sum=sum(cft66), by(class_sqd_yr_sem) 
 egen cft33_sum=sum(cft33), by(class_sqd_yr_sem) 
 gen peer_cft66= (cft66_sum-cft66)/(cft_size-1) 
 gen peer_cft33= (cft33_sum-cft33)/(cft_size-1) 
 gen peer_cfttop33=peer_cft33*gpa_top 
gen peer_cftmid33=peer_cft33*gpa_mid 
gen peer_cftbot33=peer_cft33*gpa_bot 
 gen peer_cfttop66=peer_cft66*gpa_top 
gen peer_cftmid66=peer_cft66*gpa_mid 
gen peer_cftbot66=peer_cft66*gpa_bot 


egen leadership_66pctile=pctile(leadership_cmp), p(66) by(clsyr) 
 egen leadership_33pctile=pctile(leadership_cmp), p(33) by(clsyr) 
 gen leadership66=0 
replace leadership66=1 if leadership_cmp>=leadership_66pctile 
 gen leadership33=0 
replace leadership33=1 if leadership_cmp<leadership_33pctile 
capture drop leadership_size 
egen leadership_size=count(leadership_cmp), by(class_sqd_yr_sem) 
 egen leadership66_sum=sum(leadership66), by(class_sqd_yr_sem) 
 egen leadership33_sum=sum(leadership33), by(class_sqd_yr_sem) 
 gen peer_leadership66= (leadership66_sum-leadership66)/(leadership_size-1) 
 gen peer_leadership33= (leadership33_sum-leadership33)/(leadership_size-1) 
 gen peer_leadershiptop33=peer_leadership33*gpa_top 
gen peer_leadershipmid33=peer_leadership33*gpa_mid 
gen peer_leadershipbot33=peer_leadership33*gpa_bot 
 gen peer_leadershiptop66=peer_leadership66*gpa_top 
gen peer_leadershipmid66=peer_leadership66*gpa_mid 
gen peer_leadershipbot66=peer_leadership66*gpa_bot 





label var peer_satvtop33 "Fraction of Low Third SAT-V Peers $\times$ High $\widehat{GPA}$"
label var peer_satvmid33 "Fraction of Low Third SAT-V Peers $\times$ Middle $\widehat{GPA}$"
label var peer_satvbot33 "Fraction of Low Third SAT-V Peers $\times$ Low $\widehat{GPA}$"

label var peer_satvtop66 "Fraction of High Third SAT-V Peers $\times$ High $\widehat{GPA}$"
label var peer_satvmid66 "Fraction of High Third SAT-V Peers $\times$ Middle $\widehat{GPA}$"
label var peer_satvbot66 "Fraction of High Third SAT-V Peers $\times$ Low $\widehat{GPA}$"

label var peer_satvtop25 "Fraction of Low Qtr SAT-V Peers $\times$ High $\widehat{GPA}$"
label var peer_satvmid25 "Fraction of Low Qtr SAT-V Peers $\times$ Middle $\widehat{GPA}$"
label var peer_satvbot25 "Fraction of Low Qtr SAT-V Peers $\times$ Low $\widehat{GPA}$"





* run the tertiles regression with and without all the other peer variables
xi: reg gpa peer_satvtop66 peer_satvmid66 peer_satvbot66  sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., cluster(class_sqd_yr)

test peer_satvtop66=peer_satvmid66 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot66=peer_satvmid66 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop66 peer_satvmid66 peer_satvbot66 peer_satvtop33 peer_satvmid33 peer_satvbot33 using baseline_use_tertiles_satV.tex, nocons nonotes replace se bdec(3) tdec(3) 10pct label ctitle("GPA") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')


* run the tertiles regression with and without all the other peer variables
xi: reg gpa peer_satvtop66 peer_satvmid66 peer_satvbot66 peer_satvtop25 peer_satvmid25 peer_satvbot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)

test peer_satvtop66=peer_satvmid66 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot66=peer_satvmid66 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop66 peer_satvmid66 peer_satvbot66 peer_satvtop33 peer_satvmid33 peer_satvbot33 peer_satvtop25 peer_satvmid25 peer_satvbot25 using baseline_use_tertiles_satV.tex, nocons nonotes append se  bdec(3) tdec(3) 10pct label ctitle("GPA") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')


* run the tertiles regression with and without all the other peer variables
xi: reg gpa peer_satvtop66 peer_satvmid66 peer_satvbot66 peer_satvtop33 peer_satvmid33 peer_satvbot33 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)

test peer_satvtop66=peer_satvmid66 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot66=peer_satvmid66 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop66 peer_satvmid66 peer_satvbot66 peer_satvtop33 peer_satvmid33 peer_satvbot33 using baseline_use_tertiles_satV.tex, nocons nonotes tex(frag pretty) append se bdec(3)  tdec(3) 10pct label ctitle("GPA") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')



label var peer_satvtop25 "Fraction of Low SAT-V Peers $\times$ High $\widehat{GPA}$"
label var peer_satvmid25 "Fraction of Low SAT-V Peers $\times$ Middle $\widehat{GPA}$"
label var peer_satvbot25 "Fraction of Low SAT-V Peers $\times$ Low $\widehat{GPA}$"





*****************************************************************************
*****************************************************************************

* referee 6 comment 2: use mean peer SAT scores rather than fraction high and low

* definitely see peer effects..just not non-linear


label var peer_satvtop "High $\widehat{GPA}$ $\times$ Peer $\overline{\mathrm{SAT-V}}$"
label var peer_satvmid "Middle $\widehat{GPA}$ $\times$ Peer $\overline{\mathrm{SAT-V}}$"
label var peer_satvbot "Low $\widehat{GPA}$ $\times$ Peer $\overline{\mathrm{SAT-V}}$"

replace peer_satvtop=peer_satvtop/100
replace peer_satvmid=peer_satvmid/100
replace peer_satvbot=peer_satvbot/100
xi: reg gpa peer_satvtop peer_satvmid peer_satvbot peer_satmtop peer_satmmid peer_satmbot  peer_acatop peer_acamid peer_acabot  peer_cfttop  peer_cftmid  peer_cftbot peer_acatop peer_leadtop peer_leadmid peer_leadbot  sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female i.clsyr i.semester gpa_bot gpa_top if treat==., robust cluster(class_sqd_yr)

test peer_satvtop=peer_satvmid 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot=peer_satvmid 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop peer_satvmid peer_satvbot using baseline_use_means_satV.tex, nocons nonotes tex(frag pretty) replace se bdec(3) tdec(3) label ctitle("Full Sample") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')adec(3)

xi: reg gpa peer_satvtop peer_satvmid peer_satvbot  peer_satmtop peer_satmmid peer_satmbot  peer_acatop peer_acamid peer_acabot  peer_cfttop  peer_cftmid  peer_cftbot peer_acatop peer_leadtop peer_leadmid peer_leadbot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if clsyr<=2007, robust cluster(class_sqd_yr)

test peer_satvtop=peer_satvmid 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot=peer_satvmid 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop peer_satvmid peer_satvbot using baseline_use_means_satV.tex, nocons nonotes  append se bdec(3) tdec(3) label ctitle("Classes", "2005-2007") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')adec(3)

xi: reg gpa peer_satvtop peer_satvmid peer_satvbot  peer_satmtop peer_satmmid peer_satmbot  peer_acatop peer_acamid peer_acabot  peer_cfttop  peer_cftmid  peer_cftbot peer_acatop peer_leadtop peer_leadmid peer_leadbot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==.&clsyr>2007, robust cluster(class_sqd_yr)

test peer_satvtop=peer_satvmid 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot=peer_satvmid 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop peer_satvmid peer_satvbot using baseline_use_means_satV.tex, nocons nonotes tex(frag pretty) append se bdec(3) tdec(3) label ctitle("Classes", "2008-2010") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2') adec(3)



*****************************************************************************
*****************************************************************************

* referee 6 comment 8: show treatment effect on dropout rates

* we already have this in attrit table and we also have table where we imput gpa of attriters and it still shows big treatment effect
**************************************************
* ask whether we have an effect on attrition 
**************************************************
* could only allow each person to count once for attrition
* seems to affect attrition during first semester and not second
summ attrit_ever if treat==0 & gpa_bot==1 
summ attrit_ever if treat==1 & gpa_bot==1

summ attrit_ever if treat==0 & gpa_bot==0
summ attrit_ever if treat==1 & gpa_bot==0

* there is a big change in my measured attrition during treatment years
summ attrit_ever if treat==.
summ attrit_ever if treat!=.
by clsyr, sort: tab semester
* did we drop attriters before making the data set in earlier years?



xi: dprobit attrit_ever treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & semester==2, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp using attrit_effect.tex, nocons nonotes replace se bdec(3) tdec(3) 10pct label ctitle("Low $\widehat{GPA}$")


xi: dprobit attrit_ever treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & semester==2, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp using attrit_effect.tex, nocons nonotes append se  bdec(3) tdec(3) 10pct label ctitle("Middle $\widehat{GPA}$")

xi: dprobit attrit_ever treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_top==1  & semester==2, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp using attrit_effect.tex, nocons nonotes tex(frag pretty) append se  bdec(3) tdec(3) 10pct label ctitle("High $\widehat{GPA}$")






*****************************************************************************
*****************************************************************************

* referee 6 comment 17: round standard errors and coefficients to same number of digits
* we have this in treatments_effects.tex



*****************************************************************************
*****************************************************************************

* referee 6 comment 25 and 27 : for table 10 include means of the indepedent variables and also add a dummy for bimodal SAT verbal distribution
* also regress GPA on **a polynomial** in fraction above the 75th percentile


* bruce: to do this we basically redo Table 10..see all teh code below


**************************************************
* hard to do look at treatment effect for bifurcated and not since treatment is equivalent to being bifurcated for the low GPA guys
**************************************************

gen bifurcated2=0
replace bifurcated2=1 if peer_num_mid<=6
tab treat bifurcated2


gen fraction_peers_bot=peer_num_bot/peer_num
gen fraction_peers_top=peer_num_top/peer_num

gen bifurcated4=0
replace bifurcated4=1 if fraction_peers_bot>.4 & fraction_peers_top>.4

* for referee create additional measure of bifurcated 

gen bifurcated5=0
replace bifurcated5=1 if peer_satv75>.30 & peer_satv25>.30



quantiles  fraction_peers_bot, gen(peers_botQUART) nq(4)
quantiles  fraction_peers_bot, gen(peers_botTHIRD) nq(3)
quantiles peer_satv75 , gen(peers_highSATQUART) nq(4)

gen treatment_like=0
replace treatment_like=1 if peers_botQUART==4 & peers_highSATQUART==4

gen bottom_heavy=peer_num_bot>=15
label var bifurcated4 "Fraction of Low $\widehat{GPA}$ Peers and High $\widehat{GPA}$ Peers $>.40$"

label var bifurcated5 "Fraction of High SAT-V Peers and Low SAT-V Peers $>.35$"

label var bifurcated2 "Fewer than 6 Middle $\widehat{GPA}$ Students in Squadron"


label var bottom_heavy "Greater than 15 Low $\widehat{GPA}$ Students in Squadron"

label var treatment_like "Fraction of Low $\widehat{GPA}$ Peers and High SAT-V Peers in $4^{th}$ Quartile"


* if anything, effects of bifurcation or of being bottom heavy appear to be positive on low predicted GPA guys in observational
**************************************************
* show that most measures of being bifurcated or bottom heavy predict positive effects
**************************************************

xi: reg gpa bifurcated2 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & treat==. , robust cluster(class_sqd_yr)
sum bifurcated2 if e(sample) & bifurcated2==1
local numobs=r(N)
outreg2 bifurcated2 using bifurcation_in_observational.tex, nocons nonotes replace se 10pct bdec(3) tdec(3) label ctitle("GPA") addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs')


xi: reg gpa bifurcated4 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & treat==. , robust cluster(class_sqd_yr)
sum bifurcated4 if e(sample) & bifurcated4==1
local numobs=r(N)
outreg2 bifurcated4 using bifurcation_in_observational.tex, nocons nonotes append se 10pct bdec(3) tdec(3) label ctitle("GPA") addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs')


xi: reg gpa bifurcated5 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & treat==. , robust cluster(class_sqd_yr)
sum bifurcated5 if e(sample) & bifurcated5==1
local numobs=r(N)
outreg2 bifurcated5 using bifurcation_in_observational.tex, nocons nonotes append se 10pct bdec(3) tdec(3) label ctitle("GPA")  addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs')




xi: reg gpa bottom_heavy sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_bot==1, robust cluster(class_sqd_yr)
sum bottom_heavy if e(sample) & bottom_heavy==1
local numobs=r(N)
outreg2 bottom_heavy using bifurcation_in_observational.tex, nocons nonotes append se 10pct bdec(3) tdec(3) label ctitle("GPA") addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs')




xi: reg gpa treatment_like sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_bot==1, robust cluster(class_sqd_yr)
sum treatment_like if e(sample) & treatment_like==1
local numobs=r(N)
outreg2 treatment_like using bifurcation_in_observational.tex, nocons nonotes tex(frag pretty) append se 10pct bdec(3) tdec(3) label ctitle("GPA")  addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs')



**************************************
*** Also run these bifurcation regression for the low and middle ability students *************************

gen bifurcated2_top=bifurcated2*gpa_top
gen bifurcated2_mid=bifurcated2*gpa_mid

label var bifurcated2_top "Fewer than 6 $\times$ High $\widehat{GPA}$"
label var bifurcated2_mid "Fewer than 6 $\times$ Middle $\widehat{GPA}$"

xi: reg gpa bifurcated2 bifurcated2_top bifurcated2_mid sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. , robust cluster(class_sqd_yr)
sum bifurcated2 if e(sample) & bifurcated2==1
local numobs=r(N)
outreg2 bifurcated2 bifurcated2_top bifurcated2_mid using bifurcation_in_obs_expanded.tex, nocons nonotes replace se 10pct bdec(3) tdec(3) label ctitle("GPA") addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs') adec(3)

gen bifurcated4_top=bifurcated4*gpa_top
gen bifurcated4_mid=bifurcated4*gpa_mid

label var bifurcated4_top "Fraction $>.40$ $\times$ High $\widehat{GPA}$"
label var bifurcated4_mid "Fraction $>.40$ $\times$ Middle $\widehat{GPA}$"


xi: reg gpa bifurcated4 bifurcated4_top bifurcated4_mid sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. , robust cluster(class_sqd_yr)
sum bifurcated4 if e(sample) & bifurcated4==1
local numobs=r(N)
outreg2 bifurcated4 bifurcated4_top bifurcated4_mid using bifurcation_in_obs_expanded.tex, nocons nonotes append se 10pct bdec(3) tdec(3) label ctitle("GPA") addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs') adec(3)

gen bifurcated5_top=bifurcated5*gpa_top
gen bifurcated5_mid=bifurcated5*gpa_mid

label var bifurcated5_top "Fraction $>.35$ $\times$ High $\widehat{GPA}$"
label var bifurcated5_mid "Fraction $>.35$ $\times$ Middle $\widehat{GPA}$"

xi: reg gpa bifurcated5 bifurcated5_top bifurcated5_mid sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. , robust cluster(class_sqd_yr)
sum bifurcated5 if e(sample) & bifurcated5==1
local numobs=r(N)
outreg2 bifurcated5 bifurcated5_top bifurcated5_mid using bifurcation_in_obs_expanded.tex, nocons nonotes append se 10pct bdec(3) tdec(3) label ctitle("GPA") addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs') adec(3)



gen bottom_heavy_top=bottom_heavy*gpa_top
gen bottom_heavy_mid=bottom_heavy*gpa_mid

label var bottom_heavy_top "Greater than 15 $\times$ High $\widehat{GPA}$"
label var bottom_heavy_mid "Greater than 15 $\times$ Middle $\widehat{GPA}$"

xi: reg gpa bottom_heavy bottom_heavy_top bottom_heavy_mid sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)
sum bottom_heavy if e(sample) & bottom_heavy==1
local numobs=r(N)
outreg2 bottom_heavy bottom_heavy_top bottom_heavy_mid using bifurcation_in_obs_expanded.tex, nocons nonotes append se 10pct bdec(3) tdec(3) label ctitle("GPA") addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs') adec(3)



gen treatment_like_top=treatment_like*gpa_top
gen treatment_like_mid=treatment_like*gpa_mid

label var treatment_like_top "Fraction in $4^{th}$ Quartile $\times$ High $\widehat{GPA}$"
label var treatment_like_mid "Fraction in $4^{th}$ Quartile $\times$ Middle $\widehat{GPA}$"

xi: reg gpa treatment_like treatment_like_top treatment_like_mid sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)
sum treatment_like if e(sample) & treatment_like==1
local numobs=r(N)
outreg2 treatment_like treatment_like_top treatment_like_mid using bifurcation_in_obs_expanded.tex, nocons nonotes tex(frag pretty) append 10pct se  bdec(3)tdec(3) label ctitle("GPA") addstat(Number Observations Who Meet This Definition of Bifurcation, `numobs') adec(3)









* start with baseline regression but add a polynomial in fraction above 75th
* for now just run it for bottom kids to keep it simple
gen peer_satv75_squared=peer_satv75^2
label var peer_satv75 "Fraction of High SAT-V Peers"
label var peer_satv75_squared "Fraction of High SAT-V Peers$^2$"

xi: reg gpa peer_satv75 peer_satv75_squared peer_satv25 peer_aca75 peer_aca25 peer_satm75 peer_satm25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_bot==1, robust cluster(class_sqd_yr)
outreg2 peer_satv75 peer_satv75_squared sat_v sat_m aca_cmp cft_score leadership_cmp  using quadratic_in_peer_satv75.tex, nocons nonotes tex(frag pretty) replace se bdec(3) tdec(3) 10pct label ctitle("Observational", "Group", "GPA") 


* graph the nonlinear relationship between fraction peers above 75th and gpa for the lower ability students


label var squadron_hetero_top "Peer Group SD$(\widehat{GPA})$ $\times$ High $\widehat{GPA}$"
label var squadron_hetero_top_sq "Peer Group SD$(\widehat{GPA})$ $\times$ High $\widehat{GPA}^2$"

label var squadron_hetero_mid "Peer Group SD$(\widehat{GPA})$ $\times$ Middle $\widehat{GPA}$"
label var squadron_hetero_mid_sq "Peer Group SD$(\widehat{GPA})$ $\times$ Middle $\widehat{GPA}^2$"

label var squadron_hetero_bot "Peer Group SD$(\widehat{GPA})$ $\times$ Low $\widehat{GPA}$"
label var squadron_hetero_bot_sq "Peer Group SD$(\widehat{GPA})$ $\times$ Low $\widehat{GPA}^2$"

xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 squadron_hetero_top squadron_hetero_top_sq squadron_hetero_mid squadron_hetero_mid_sq squadron_hetero_bot squadron_hetero_bot_sq sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 squadron_hetero_top squadron_hetero_top_sq squadron_hetero_mid squadron_hetero_mid_sq squadron_hetero_bot squadron_hetero_bot_sq  using  quadratic_interaction_table2.tex,  nocons nonotes tex(frag pretty) replace se bdec(3) tdec(3) 10pct label ctitle("Observational", "Group", "GPA") 

xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 squadron_hetero_top squadron_hetero_top_sq squadron_hetero_mid squadron_hetero_mid_sq squadron_hetero_bot squadron_hetero_bot_sq sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 squadron_hetero_top squadron_hetero_top_sq squadron_hetero_mid squadron_hetero_mid_sq squadron_hetero_bot squadron_hetero_bot_sq  using quadratic_interaction_table2.tex,  nocons nonotes tex(frag pretty) replace se bdec(3) tdec(3) 10pct label ctitle("Controll", "Group", "GPA") 

 

***********************************************
* show the basic peer effects regressions in the observational, control and treatment
**************************************************
* do for both linear in means and nonlinear
* observational
xi: reg gpa peer_satv75 peer_satv25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & semester==1, robust cluster(class_sqd_yr)
outreg2 using baseline_linear.tex, nocons nonotes replace se tdec(3) label cttop("Observational") 
outreg2 gpa peer_satv75 peer_satv25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female using summary_stats.tex, nocons nonotes replace se tdec(3) label cttop("Observational", "Group" )sum

* control
xi: reg gpa peer_satv75 peer_satv25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0 & semester==1, robust cluster(class_sqd_yr)
outreg2 using baseline_linear.tex, nocons nonotes append se tdec(3) label cttop("Control")
outreg2 gpa peer_satv75 peer_satv25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female using summary_stats.tex, nocons nonotes append se tdec(3) label cttop("Control", "Group" )sum


* treat
xi: reg gpa peer_satv75 peer_satv25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==1 & semester==1, robust cluster(class_sqd_yr)
label var  _Iclsyr_2006 "Class=2006"
label var  _Iclsyr_2007 "Class=2007"
label var  _Iclsyr_2008 "Class=2008"
label var  _Iclsyr_2009 "Class=2009"
label var  _Iclsyr_2010 "Class=2010"
label var  _Iclsyr_2011 "Class=2011"
label var  _Iclsyr_2012 "Class=2012"
label var  _Isemester_2 "Semester=Spring"
outreg2 using baseline_linear.tex, nocons nonotes append tex(frag pretty) se tdec(3)  label cttop("Treatment")
outreg2 gpa peer_satv75 peer_satv25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female  using summary_stats.tex, nocons nonotes append tex(frag pretty) se tdec(3) label cttop("Treatment", "Group" )sum


* test whether middle ability students have a different coeff than top and bottom
* observational
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)

test peer_satvtop75=peer_satvmid75 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot75=peer_satvmid75 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 using baseline_nonlinear.tex, nocons nonotes replace se tdec(3) label cttop("Observational", "Group") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')






* control
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
test peer_satvtop75=peer_satvmid75 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot75=peer_satvmid75 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 using baseline_nonlinear.tex, nocons nonotes append se tdec(3) label cttop("Control", "Group") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')


* treat
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==1, robust cluster(class_sqd_yr)
test peer_satvtop75=peer_satvmid75 
local F1 = r(F)
local P1 = r(p)
test peer_satvbot75=peer_satvmid75 
local F1 = r(F)
local P1 = r(p)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 using baseline_nonlinear.tex, nocons nonotes append tex(frag pretty) se tdec(3) label cttop("Treatment", "Group") addstat(F Peer Effect High v Middle, `F1', p-value, `P1', F Peer Effect Low v Middle, `F2', p-value, `P2')



********************************************************************
*Table 2 --- final**show peer effects in observational and control***
*********************************************************************



*observational linear unrestricted*
xi: reg gpa peer_satv75  peer_satv25 peer_satm75  peer_satm25 peer_aca75  peer_aca25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)
test peer_satv75  peer_satv25  peer_satm75  peer_satm25 peer_aca75  peer_aca25
local F2 = r(F)
local P2 = r(p)
test peer_satv75  peer_satv25
local F1 = r(F)
local P1 = r(p)
outreg2 peer_satv75  peer_satv25 using table2_final_obs.tex, nocons nonotes replace  bdec(3) tdec(3) se 10pct label ct("GPA") addstat(F All Peer Variables, `F2', p-value All, `P2', F Peer SAT Verbal, `F1', p-value SAT Verbal, `P1') adec(3)


*observational linear restricted*
xi: reg gpa peer_satv75  peer_satv25  sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)
test peer_satv75  peer_satv25
local F1 = r(F)
local P1 = r(p)
outreg2 peer_satv75  peer_satv25 using table2_final_obs.tex, nocons nonotes append bdec(3) tdec(3) se 10pct label ct("GPA") addstat(F Peer SAT Verbal, `F1', p-value SAT Verbal, `P1')  adec(3)



*observational nonlinear unrestricted*

xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25

local F5 = r(F)
local P5 = r(p)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F4 = r(F)
local P4 = r(p)
test peer_satvtop75 = peer_satvmid75
local F1 = r(F)
local P1 = r(p)
test peer_satvtop75 = peer_satvbot75
local F2 = r(F)
local P2 = r(p)
test peer_satvbot75 = peer_satvmid75
local F3 = r(F)
local P3 = r(p)
outreg2  peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 using table2_final_obs.tex,   nocons nonotes append bdec(3) tdec(3) se 10pct label ct("GPA") addstat(F All Peer Variables, `F5', p-value All, `P5', F Peer SAT Verbal, `F4', p-value SAT Verbal, `P4', F Peer Effect High v Middle, `F1', p-value T v M, `P1', F Peer Effect High v Low, `F2', p-value T v B, `P2', F Peer Effect Low v Middle, `F3', p-value B v M, `P3' ) adec(3)

*observational nonlinear restricted*
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F4 = r(F)
local P4 = r(p)
test peer_satvtop75 = peer_satvmid75
local F1 = r(F)
local P1 = r(p)
test peer_satvtop75 = peer_satvbot75
local F2 = r(F)
local P2 = r(p)
test peer_satvbot75 = peer_satvmid75
local F3 = r(F)
local P3 = r(p)
outreg2  peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 using table2_final_obs.tex, nocons nonotes append tex(frag pretty) bdec(3) tdec(3) se 10pct label ct("GPA") sortvar(peer_satv75  peer_satv25 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25)   addstat(F Peer SAT Verbal, `F4', p-value SAT Verbal, `P4', F Peer Effect High v Middle, `F1', p-value T v M, `P1', F Peer Effect High v Low, `F2', p-value T v B, `P2', F Peer Effect Low v Middle, `F3', p-value B v M, `P3') adec(3)

*Control linear unrestricted*
xi: reg gpa peer_satv75  peer_satv25 peer_satm75  peer_satm25 peer_aca75  peer_aca25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
test peer_satv75  peer_satv25  peer_satm75  peer_satm25 peer_aca75  peer_aca25
local F2 = r(F)
local P2 = r(p)
test peer_satv75  peer_satv25
local F1 = r(F)
local P1 = r(p)
outreg2 peer_satv75  peer_satv25 using table2_final_con.tex, nocons nonotes replace bdec(3) tdec(3) se 10pct label ct("GPA") addstat(F All Peer Variables, `F2', p-value All, `P2', F Peer SAT Verbal, `F1', p-value SAT Verbal, `P1') adec(3)


*Controll linear restricted*
xi: reg gpa peer_satv75  peer_satv25  sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
test peer_satv75  peer_satv25
local F1 = r(F)
local P1 = r(p)
outreg2 peer_satv75  peer_satv25 using table2_final_con.tex, nocons nonotes append bdec(3) tdec(3) se 10pct label ct("GPA") addstat(F Peer SAT Verbal, `F1', p-value SAT Verbal, `P1')  adec(3)

*Control nonlinear unrestricted*

xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25

local F5 = r(F)
local P5 = r(p)

test peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_satmtop25 peer_satmmid25 peer_satmbot25
local F6 = r(F)
local P6 = r(p)

test peer_acatop75 peer_acamid75 peer_acabot75 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25
local F7 = r(F)
local P7 = r(p)


test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F4 = r(F)
local P4 = r(p)
test peer_satvtop75 = peer_satvmid75
local F1 = r(F)
local P1 = r(p)
test peer_satvtop75 = peer_satvbot75
local F2 = r(F)
local P2 = r(p)
test peer_satvbot75 = peer_satvmid75
local F3 = r(F)
local P3 = r(p)
outreg2  peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 using table2_final_con.tex, nocons nonotes append  bdec(3) tdec(3) se 10pct label ct("GPA") addstat(F All Peer Variables, `F5', p-value All, `P5', F Peer SAT Verbal, `F4', p-value SAT Verbal, `P4', F Peer Effect High v Middle, `F1', p-value T v M, `P1', F Peer Effect High v Low, `F2', p-value T v B, `P2', F Peer Effect Low v Middle, `F3', p-value B v M, `P3') adec(3)

*Control nonlinear restricted *
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top   i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F4 = r(F)
local P4 = r(p)
test peer_satvtop75 = peer_satvmid75
local F1 = r(F)
local P1 = r(p)
test peer_satvtop75 = peer_satvbot75
local F2 = r(F)
local P2 = r(p)
test peer_satvbot75 = peer_satvmid75
local F3 = r(F)
local P3 = r(p)
outreg2  peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 using table2_final_con.tex, nocons nonotes append tex(frag pretty) bdec(3) tdec(3) se 10pct label ct("GPA") sortvar(peer_satv75  peer_satv25 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25)  addstat(F Peer SAT Verbal, `F4', p-value SAT Verbal, `P4', F Peer Effect High v Middle, `F1', p-value T v M, `P1', F Peer Effect High v Low, `F2', p-value T v B, `P2', F Peer Effect Low v Middle, `F3', p-value B v M, `P3') adec(3)



**************************************************
* show the big negative treatment effect
**************************************************
xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester , robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using treatment_effect.tex, nocons nonotes replace se bdec(3) tdec(3) 10pct label ctitle("All Students")


xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using treatment_effect.tex, nocons nonotes append se bdec(3) tdec(3) 10pct label ctitle("Low $\widehat{GPA}$")


xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using treatment_effect.tex, nocons nonotes append se  bdec(3)  tdec(3) 10pct label ctitle("Middle $\widehat{GPA}$")

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_top==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using treatment_effect.tex, nocons nonotes tex(frag pretty) append se  bdec(3)  tdec(3) 10pct label ctitle("High $\widehat{GPA}$")




**************************************************
* test the key non-linear regression within subsets of years
**************************************************
* first three years of observational
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75  peer_satvtop25 peer_satvmid25 peer_satvbot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & clsyr>=2005 & clsyr<=2007 , robust cluster(class_sqd_yr)
test peer_satvtop75=peer_satvmid75
local F1 = r(F)
local P1 = r(p) 

test peer_satvbot25=peer_satvmid25
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75  peer_satvtop25 peer_satvmid25 peer_satvbot25 using non_linear_subsample.tex, nocons nonotes replace se bdec(3) tdec(3) 10pct label ctitle("Classes", "2005-2007", "GPA") addstat(F: Peer Effect High $-$ Peer Effect Middle , `F1', p-value, `P1', F: Peer Effect Low $-$ Peer Effect Middle, `F2', p-value, `P2')




* second three years of observational
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75  peer_satvtop25 peer_satvmid25 peer_satvbot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & clsyr>=2008 & clsyr<=2010 , robust cluster(class_sqd_yr)
test peer_satvtop75=peer_satvmid75 
local F1 = r(F)
local P1 = r(p) 
test peer_satvbot75=peer_satvmid75 
local F2 = r(F)
local P2 = r(p)
outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75  peer_satvtop25 peer_satvmid25 peer_satvbot25 using non_linear_subsample.tex, nocons nonotes tex(frag pretty) append se bdec(3)  tdec(3) 10pct label ctitle("Classes", "2008-2010", "GPA") addstat(F: Peer Effect High $-$ Peer Effect Middle , `F1', p-value, `P1', F: Peer Effect Low $-$ Peer Effect Middle, `F2', p-value, `P2')









**************************************************
* further test whether the process changed by combining the samples
**************************************************

xi: reg gpa obser_satv75top obser_satv75mid obser_satv75bot control_satv75top control_satv75mid control_satv75bot  obser_satv25top obser_satv25mid obser_satv25bot control_satv25top control_satv25mid control_satv25bot  i.control*peer_satmtop75  i.control*peer_satmmid75  i.control*peer_satmbot75  i.control*peer_acatop75  i.control*peer_acamid75  i.control*peer_acabot75  i.control*peer_satmtop25  i.control*peer_satmmid25  i.control*peer_satmbot25  i.control*peer_acatop25  i.control*peer_acamid25  i.control*peer_acabot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat!=1, robust cluster(class_sqd_yr)
test obser_satv75bot= control_satv75bot
local F1 = r(F)
local P1 = r(p) 

test obser_satv25mid= control_satv25mid
local F2 = r(F)
local P2 = r(p) 

outreg2 obser_satv75top obser_satv75mid obser_satv75bot control_satv75top control_satv75mid control_satv75bot  obser_satv25top obser_satv25mid obser_satv25bot control_satv25top control_satv25mid control_satv25bot  using observ_v_control.tex, nocons nonotes replace se tdec(3) 10pct label ctitle("GPA") addstat(F: Peer Effect for Low Group: Observational v Control , `F1', p-value, `P1', F: Peer Effect for Middle Group: Observational v Control , `F2', p-value, `P2') adec(3)

xi: reg gpa obser_satv75top obser_satv75mid obser_satv75bot control_satv75top control_satv75mid control_satv75bot  obser_satv25top obser_satv25mid obser_satv25bot control_satv25top control_satv25mid control_satv25bot  sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat!=1, robust cluster(class_sqd_yr)
test obser_satv75bot= control_satv75bot
local F1 = r(F)
local P1 = r(p) 


test obser_satv25mid= control_satv25mid
local F2 = r(F)
local P2 = r(p) 

outreg2 obser_satv75top obser_satv75mid obser_satv75bot control_satv75top control_satv75mid control_satv75bot obser_satv25top obser_satv25mid obser_satv25bot control_satv25top control_satv25mid control_satv25bot using observ_v_control.tex, nocons nonotes tex(frag pretty) append se tdec(3) 10pct label ctitle("GPA") addstat(F: Peer Effect for Low Group: Observational v Control , `F1', p-value, `P1', F: Peer Effect for Middle Group: Observational v Control , `F2', p-value, `P2') adec(3)




	

************************h*********************************************
* run the endogenous model bc it offers better statistical precision
**********************************************************************

xi: reg gpa peer_gpa sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)
outreg2 peer_gpa using endogenous_table.tex, nocons nonotes replace 10pct se  bdec(3)  tdec(3) label ctitle("Observational")



xi: reg gpa peer_gpa sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
outreg2 peer_gpa using endogenous_table.tex, nocons nonotes append se  bdec(3)  tdec(3) 10pct label ctitle("Control")


xi: reg gpa peer_gpa sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==1, robust cluster(class_sqd_yr)
outreg2 peer_gpa using endogenous_table.tex, nocons nonotes  append se  bdec(3)  tdec(3) 10pct label ctitle("Treatment")

* run the endogenous model stacked so that I can easily test equality of coefficients

xi: reg gpa obser_peer_gpa control_peer_gpa sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat!=1, robust cluster(class_sqd_yr)
test obser_peer_gpa=control_peer_gpa
local F1 = r(F)
local P1 = r(p) 
outreg2 obser_peer_gpa control_peer_gpa using endogenous_table_stacked.tex, nocons nonotes tex(frag pretty) replace se tdec(3) 10pct label cttop("Observational & Control") addstat(F: Peer Effect for Low Group: Observational v Control , `F1', p-value, `P1')


***************************************************************************
*run endogenous by treat, contro, obser with sep coef for low middl high***
**************************************************************************

xi: reg gpa peer_gpatop peer_gpamid peer_gpabot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==.  , robust cluster(class_sqd_yr)

outreg2 peer_gpatop peer_gpamid peer_gpabot using endogenous_table.tex, nocons nonotes append se bdec(3) tdec(3) 10pct label ctitle("Observational")

xi: reg gpa peer_gpatop peer_gpamid peer_gpabot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic  asian female gpa_bot gpa_top i.clsyr i.semester if treat==0  , robust cluster(class_sqd_yr)
outreg2 peer_gpatop peer_gpamid peer_gpabot using endogenous_table.tex, nocons nonotes  append se bdec(3)  tdec(3) 10pct label ctitle("Control")

xi: reg gpa peer_gpatop peer_gpamid peer_gpabot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic  asian female gpa_bot gpa_top i.clsyr i.semester if treat==1  , robust cluster(class_sqd_yr)
outreg2 peer_gpatop peer_gpamid peer_gpabot using endogenous_table.tex, nocons nonotes tex(frag pretty) append se  bdec(3)  tdec(3) 10pct label ctitle("Treatment") sortvar(peer_gpa peer_gpatop peer_gpamid peer_gpabot)




label var resp_treat "Treatment Group"
label var resp_gpa_bot "Low $\widehat{GPA}$ $\times$ Treatment Group"

 
reg  low_gpa_study_partners treat_bot resp_treat resp_gpa_bot if semester==1


xi: reg low_gpa_study treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1, robust cluster(class_sqd_yr)
outreg2 treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp  using study_partners_table.tex, nocons nonotes replace bdec(3) tdec(3) se 10pct label ctitle("Number", "Low $\widehat{GPA}$", "Study", "Partners") 

xi: reg high_gpa_study treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1, robust cluster(class_sqd_yr)
outreg2 treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp  using study_partners_table.tex, nocons nonotes append bdec(3) tdec(3) se 10pct label ctitle("Number", "High $\widehat{GPA}$", "Study", "Partners")


xi: reg mid_gpa_study treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1, robust cluster(class_sqd_yr)
outreg2 treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp  using study_partners_table.tex, nocons nonotes append bdec(3) tdec(3) se 10pct label ctitle("Number", "Middle $\widehat{GPA}$", "Study", "Partners")


xi: reg low_gpa_friends treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1, robust cluster(class_sqd_yr)
outreg2  treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp  using study_partners_table.tex, nocons nonotes append bdec(3) tdec(3) se 10pct label ctitle("Number", "Low $\widehat{GPA}$", "Friends")


xi: reg high_satV_study_partners treat_bot treat_top resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1, robust cluster(class_sqd_yr)
outreg2 treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp  using study_partners_table.tex, nocons nonotes append bdec(3) tdec(3) se 10pct label ctitle("Number", "High SAT-V", "Study", "Partners")


xi: reg high_satV_friends treat_bot treat_top resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1, robust cluster(class_sqd_yr)
outreg2  treat_bot resp_treat resp_gpa_bot sat_v sat_m aca_cmp cft_score leadership_cmp  using study_partners_table.tex, nocons nonotes tex(frag pretty) append bdec(3) tdec(3) se 10pct label ctitle("Number", "High SAT-V", "Friends")





* show how squadrons were pretty bifurcated in the treatment group relative to control and observational
tab  num_lowGPAhat num_highSATV if first_ob==1 & treat==0
tab  num_lowGPAhat num_highSATV if first_ob==1 & treat==.
tab  num_lowGPAhat num_highSATV if first_ob==1 & treat==1




**************************************************
* show the treatment effects if we assign attriters a gpa of 1.5
**************************************************

gen gpa_adj=gpa
replace gpa_adj=1.5 if gpa==.

xi: reg gpa_adj treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using treatment_effect_adj.tex, nocons nonotes replace se bdec(3) tdec(3) 10pct label ctitle("Low $\widehat{GPA}$")


xi: reg gpa_adj treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using treatment_effect_adj.tex, nocons nonotes append se  bdec(3)  tdec(3) 10pct label ctitle("Middle $\widehat{GPA}$")

xi: reg gpa_adj treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_top==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using treatment_effect_adj.tex, nocons nonotes tex(frag pretty) append se  bdec(3)  tdec(3) 10pct label ctitle("High $\widehat{GPA}$")


**************************************************
* show the treatment effects by race
**************************************************

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 , robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using effects_by_race.tex, nocons nonotes replace se bdec(3) tdec(3) 10pct label ctitle("All", "Students", "GPA") 


xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & black==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using effects_by_race.tex, nocons nonotes append se bdec(3) tdec(3) 10pct label ctitle("Black", "Students", "GPA") 

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & hisp==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using effects_by_race.tex, nocons nonotes append se  bdec(3) tdec(3) 10pct label ctitle("Hispanic", "Students", "GPA") 

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & female==0 , robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using effects_by_race.tex, nocons nonotes append se bdec(3) tdec(3) 10pct label ctitle("Male", "Students", "GPA") 

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & black==0 & hispanic==0 & female==0, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using effects_by_race.tex, nocons nonotes append se bdec(3) tdec(3) 10pct label ctitle("White", "Male", "Students", "GPA") 

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & female==1 , robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using effects_by_race.tex, nocons nonotes tex(frag pretty) append se bdec(3) tdec(3) 10pct label ctitle("Female", "Students", "GPA") 



xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 , robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using mid_effects_by_race.tex, nocons nonotes replace se bdec(3) tdec(3) 10pct label ctitle("All", "Students", "GPA") 


xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & black==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using mid_effects_by_race.tex, nocons nonotes append se bdec(3) tdec(3) 10pct label ctitle("Black", "Students", "GPA") 

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & hisp==1, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using mid_effects_by_race.tex, nocons nonotes append se  bdec(3) tdec(3) 10pct label ctitle("Hispanic", "Students", "GPA") 

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & female==0 , robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using mid_effects_by_race.tex, nocons nonotes append se bdec(3) tdec(3) 10pct label ctitle("Male", "Students", "GPA") 

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & black==0 & hispanic==0 & female==0, robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using mid_effects_by_race.tex, nocons nonotes append se bdec(3) tdec(3) 10pct label ctitle("White", "Male", "Students", "GPA") 

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & female==1 , robust cluster(class_sqd_yr)
outreg2 treat sat_v sat_m aca_cmp cft_score leadership_cmp  using mid_effects_by_race.tex, nocons nonotes tex(frag pretty) append se bdec(3) tdec(3) 10pct label ctitle("Female", "Students", "GPA") 





**************************************************
* treatment effect concentrated among low end students with > 45% of peers low end gpa hat
**************************************************
xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & fraction_peers_bot>.45 , robust cluster(class_sqd_yr)
outreg2 using effect_in_concentrated_squadrons.tex, nocons nonotes replace se tdec(3) 10pct label cttop("Squadron Greater Than 45\% Low $\widehat{GPA}$") 


xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & fraction_peers_bot<.45 , robust cluster(class_sqd_yr)
outreg2 using effect_in_concentrated_squadrons.tex, nocons nonotes tex(frag pretty) append se tdec(3) 10pct label cttop("Squadron Less Than 45\% Low $\widehat{GPA}$") 



egen squad_size=count(id), by(class_sqd_yr_sem)
gen peers= squad_size-1
gen frac_peer_num_bot=peer_num_bot/peers
gen frac_peer_num_mid=peer_num_mid/peers
gen frac_peer_num_top=peer_num_top/peers
gen frac_like= frac_peer_num_bot
replace frac_like= frac_peer_num_mid if gpa_mid==1
replace frac_like= frac_peer_num_top if gpa_top==1
gen frac_like_study= fraction_study_low_gpa
replace frac_like_study= fraction_study_high_gpa if gpa_top==1
replace frac_like_study= fraction_study_mid_gpa if gpa_mid==1
gen frac_like_treat= frac_like*treat
gen frac_like_treat_top =frac_like* treat_top
gen frac_like_treat_mid =frac_like* treat_mid
gen frac_like_treat_bot =frac_like* treat_bot
gen frac_like_top =frac_like* gpa_top
gen frac_like_mid =frac_like* gpa_mid
gen frac_like_bot =frac_like* gpa_bot
gen frac_like_con_bot =frac_like* gpa_bot*control
gen frac_like_con_mid =frac_like* gpa_mid*control
gen frac_like_con_top =frac_like* gpa_top*control

gen control_bot = control*gpa_bot
gen control_mid = control*gpa_mid
gen control_top = control*gpa_top

sort clsyr id semester

save experiment_survey_merged, replace





**************************************************
* there were numerous treatment squadrons with low GPAs
**************************************************

table squadron if treat==1 & gpa_bot==1 & clsyr==2012, c(mean gpa n gpa) format(%5.3f) row col

table squadron if treat==0 & gpa_bot==1 & clsyr==2012, c(mean gpa n gpa) format(%5.3f) row col


* overall histogram of gpa in 2012 treatment and control low end guys
twoway (hist gpa if gpa_bot==1 & treat==1 & clsyr==2012, color(red) ) (hist gpa if gpa_bot==1 & treat==0 & clsyr==2012, color(blue)), legend(label( 1 treatment) label( 2 control))


* collapse the data and make a histogram of the means

collapse gpa treat if treat!=. & gpa_bot==1, by(clsyr squadron)

twoway (hist gpa if treat==1 & clsyr==2012, fraction color(red) ) (hist gpa if treat==0 & clsyr==2012, fraction color(blue)), legend(label( 1 treatment) label( 2 control))



**************************************************
* show that it does matter in bifurcated squadrons
**************************************************
* look at bifurcated squadrons in the observational...those with 16 or more bottom kids and 12 or more top kids....

* it sort of supports our point but the results on bifurcated squadrons are very squirelly and are not robust to tweaks in the definition of bifurcated

clear
use experiment_survey_merged

gen bifurcated=0
replace bifurcated=1 if peer_num_bot>=16 & peer_num_top>=12

xi: reg gpa peer_num_bottop  peer_num_botmid  peer_num_botbot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & bifurcated==1, robust cluster(class_sqd_yr)
outreg2 peer_num_bottop  peer_num_botmid  peer_num_botbot using nonlin_number_peers_bottom.tex, nocons nonotes append se tdec(3) 10pct label cttop("Bifurcated Squadrons Observational ")


* true bifurcation works in both the observational and the experimental groups
* its something else about the treatment formation that is bad

xi: reg gpa bifurcated4 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & treat==. , robust cluster(class_sqd_yr)

xi: reg gpa bifurcated4 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & treat!=. , robust cluster(class_sqd_yr)


* for low end guys there is something negative about being in the highest quartile of top and bottom guys

quantiles peer_num_bot, gen(bottom_peersQUART) nq(4)

quantiles peer_num_top, gen(top_peersQUART) nq(4)

* the low end guys really end up with lots of low end peers...more than lots of high end peers
table  bottom_peersQUART top_peersQUART if treat==1 & gpa_bot==1 & clsyr==2012, c(mean gpa n gpa)







**************************************************
* ask whether we could have imagined the peer effects
**************************************************
* look at F statistic of peer variables in each of observational, control, treatment
* 6 peer variables are proportion high and low for math, verbal, aca
* consider both linear and non-linear models
* for now I am just showing non-linear bc the F on the linear is borderline and we don't fully believe that

****************************************************************************
****************************************************************************
* Observational Group Lowest Third
xi: reg gpa peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_bot==1, robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25
local F1 = r(F)
local P1 = r(p)

test peer_satv75 peer_satv25 
local F2 = r(F)
local P2 = r(p)

test peer_satm75 peer_satm25 
local F3 = r(F)
local P3 = r(p)


outreg2 peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 using checkpeereffects_nonlinear_observational.tex, nocons nonotes replace se tdec(3) 10pct label cttop("Lowest Third") addstat(F All Peer Variables, `F1', P All Peer Variables, `P1', F Peer SAT Verbal, `F2', P Peer SAT Verbal, `P2', F Peer SAT Math, `F3', P Peer SAT Math, `P3')


* Observational Group Middle Third
xi: reg gpa peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_mid==1, robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25
local F1 = r(F)
local P1 = r(p)

test peer_satv75 peer_satv25 
local F2 = r(F)
local P2 = r(p)

test peer_satm75 peer_satm25 
local F3 = r(F)
local P3 = r(p)


outreg2 peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 using checkpeereffects_nonlinear_observational.tex, nocons nonotes append se tdec(3) 10pct label cttop("Middle Third") addstat(F All Peer Variables, `F1', P All Peer Variables, `P1', F Peer SAT Verbal, `F2', P Peer SAT Verbal, `P2', F Peer SAT Math, `F3', P Peer SAT Math, `P3')



* Observational Group Top Third
xi: reg gpa peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_top==1, robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25
local F1 = r(F)
local P1 = r(p)

test peer_satv75 peer_satv25 
local F2 = r(F)
local P2 = r(p)

test peer_satm75 peer_satm25 
local F3 = r(F)
local P3 = r(p)

outreg2 peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 using checkpeereffects_nonlinear_observational.tex, nocons nonotes tex(frag pretty) append se tdec(3) 10pct label cttop("Top Third") addstat(F All Peer Variables, `F1', P All Peer Variables, `P1', F Peer SAT Verbal, `F2', P Peer SAT Verbal, `P2', F Peer SAT Math, `F3', P Peer SAT Math, `P3')


**********************************************************************
*********************************************************************
** Try looking at peer variables Just in Bottom Group in Treatment, Control Observational

****************************************************************************
****************************************************************************
* Observational Group Lowest Third
xi: reg gpa peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==. & gpa_bot==1, robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25
local F1 = r(F)
local P1 = r(p)

test peer_satv75 peer_satv25 
local F2 = r(F)
local P2 = r(p)

test peer_satm75 peer_satm25 
local F3 = r(F)
local P3 = r(p)


outreg2 peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 using checkpeereffects_nonlinear_bottomthird.tex, nocons nonotes replace se tdec(3) 10pct label cttop("Observational Group: Lowest Third") addstat(F All Peer Variables, `F1', P All Peer Variables, `P1', F Peer SAT Verbal, `F2', P Peer SAT Verbal, `P2', F Peer SAT Math, `F3', P Peer SAT Math, `P3')


* Control Group Bottom Third
xi: reg gpa peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0 & gpa_bot==1, robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25
local F1 = r(F)
local P1 = r(p)

test peer_satv75 peer_satv25 
local F2 = r(F)
local P2 = r(p)

test peer_satm75 peer_satm25 
local F3 = r(F)
local P3 = r(p)


outreg2 peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 using checkpeereffects_nonlinear_bottomthird.tex, nocons nonotes append se tdec(3) 10pct label cttop("Control Group, Lowest Third") addstat(F All Peer Variables, `F1', P All Peer Variables, `P1', F Peer SAT Verbal, `F2', P Peer SAT Verbal, `P2', F Peer SAT Math, `F3', P Peer SAT Math, `P3')



* Treatment Group Bottom Third
xi: reg gpa peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==1 & gpa_bot==1, robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25
local F1 = r(F)
local P1 = r(p)

test peer_satv75 peer_satv25 
local F2 = r(F)
local P2 = r(p)

test peer_satm75 peer_satm25 
local F3 = r(F)
local P3 = r(p)

outreg2 peer_satv75 peer_satm75 peer_aca75 peer_satm25 peer_satv25 peer_aca25 using checkpeereffects_nonlinear_bottomthird.tex, nocons nonotes tex(frag pretty) append se tdec(3) 10pct label cttop("Treatment Group, Lowest Third") addstat(F All Peer Variables, `F1', P All Peer Variables, `P1', F Peer SAT Verbal, `F2', P Peer SAT Verbal, `P2', F Peer SAT Math, `F3', P Peer SAT Math, `P3')







* look at F statistic of all peer variables in observational treat control

xi: reg  gpa peer_satv75 peer_satm75 peer_aca75 peer_lead75 peer_cft75 peer_satm25 peer_satv25 peer_aca25 peer_lead25 peer_cft25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_lead75 peer_cft75 peer_satm25 peer_satv25 peer_aca25 peer_lead25 peer_cft25 


xi: reg gpa peer_satv75 peer_satm75 peer_aca75 peer_lead75 peer_cft75 peer_satm25 peer_satv25 peer_aca25 peer_lead25 peer_cft25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_lead75 peer_cft75 peer_satm25 peer_satv25 peer_aca25 peer_lead25 peer_cft25



xi: reg gpa peer_satv75 peer_satm75 peer_aca75 peer_lead75 peer_cft75 peer_satm25 peer_satv25 peer_aca25 peer_lead25 peer_cft25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==1, robust cluster(class_sqd_yr)

test peer_satv75 peer_satm75 peer_aca75 peer_lead75 peer_cft75 peer_satm25 peer_satv25 peer_aca25 peer_lead25 peer_cft25

**********************************************************************
*********************************************************************
* try f test of all peer variables using the fully interacted model (interact all peer variables with top middle bottom)
**********************************************************************
*********************************************************************
* Observational group
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25

local F1 = r(F)
local P1 = r(p)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F2 = r(F)
local P2 = r(p)

test peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_satmtop25 peer_satmmid25 peer_satmbot25
local F3 = r(F)
local P3 = r(p)

outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 using checkpeereffects_nonlinear_combinedmodel.tex, nocons nonotes replace se tdec(3) 10pct label cttop("Observational Group ") addstat(F All Peer Variables, `F1', p-value, `P1', F Peer SAT Verbal, `F2', p-value, `P2', F Peer SAT Math, `F3', p-value, `P3')


**********************************************************************
*********************************************************************
* try f test of all peer variables using the fully interacted model (interact all peer variables with top middle bottom) also include CFT and Leadership
**********************************************************************
*********************************************************************
* Observational group
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 peer_cfttop75 peer_cftmid75 peer_cftbot75 peer_cfttop25 peer_cftmid25 peer_cftbot25 peer_leadtop75 peer_leadmid75 peer_leadbot75 peer_leadtop25 peer_leadmid25 peer_leadbot25  sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)


test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F2 = r(F)
local P2 = r(p)

outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25   using fully_interacted.tex, nocons nonotes tex(frag pretty) replace se bdec (3) tdec(3) 10pct label ctitle("GPA") addstat( F Peer SAT Verbal Variables, `F2', p-value, `P2') adec(3)





*************************************************************
*************************************************************
* run Bonferroni's ttest on the peer variables *

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25, mtest(bonferroni)




* Control group
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25

local F1 = r(F)
local P1 = r(p)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F2 = r(F)
local P2 = r(p)

test peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_satmtop25 peer_satmmid25 peer_satmbot25
local F3 = r(F)
local P3 = r(p)

outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 using checkpeereffects_nonlinear_combinedmodel.tex, nocons nonotes append se tdec(3) 10pct label cttop("Control Group ") addstat(F All Peer Variables, `F1', p-value, `P1', F Peer SAT Verbal, `F2', p-value, `P2', F Peer SAT Math, `F3', p-value, `P3')


 
* Treatment group
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==1, robust cluster(class_sqd_yr)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25

local F1 = r(F)
local P1 = r(p)

test peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25
local F2 = r(F)
local P2 = r(p)

test peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_satmtop25 peer_satmmid25 peer_satmbot25
local F3 = r(F)
local P3 = r(p)

outreg2 peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satmtop75 peer_satmmid75 peer_satmbot75 peer_acatop75 peer_acamid75 peer_acabot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 peer_satmtop25 peer_satmmid25 peer_satmbot25 peer_acatop25 peer_acamid25 peer_acabot25 using checkpeereffects_nonlinear_combinedmodel.tex, nocons nonotes tex(frag pretty) append se tdec(3) 10pct label cttop("Treatment Group ") addstat(F All Peer Variables, `F1', p-value, `P1', F Peer SAT Verbal, `F2', p-value, `P2', F Peer SAT Math, `F3', p-value, `P3')




* is the effect of verbal SAT75 robust to bootstrapping different classes by choosing 30 squadrons at random and running the regression?

* not sure about this yet....maybe we shouldn't be asking about likelihood that we see the effect in a single year/ that its statistically significant

* bootstrap "xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., cluster(class_sqd_yr_sem)" "_b" , cluster(class_sqd_yr_sem) size(120) reps(1000) saving(bstrap_verbal_sats_nonlinear8)



* xi: reg gpa obser_peer_gpatop obser_peer_gpamid obser_peer_gpabot treat_peer_gpatop treat_peer_gpamid treat_peer_gpabot control_peer_gpatop control_peer_gpamid control_peer_gpabot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic control_peer_gpabot asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)

* test obser_peer_gpatop=control_peer_gpatop
* test obser_peer_gpabot=treat_peer_gpabot



* re-run this but interact my own level with peer gPA...exclude the treatment group from the analysis...so that it doesn't mess up coefficients on the other controls

xi: reg gpa obser_peer_gpatop obser_peer_gpamid obser_peer_gpabot control_peer_gpatop control_peer_gpamid control_peer_gpabot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic control_peer_gpabot asian female gpa_bot gpa_top i.clsyr i.semester if treat!=1, robust cluster(class_sqd_yr)
test obser_peer_gpatop=control_peer_gpatop
local F1 = r(F)
local P1 = r(p) 
test obser_peer_gpabot=control_peer_gpabot
local F2 = r(F)
local P2 = r(p)

outreg2 obser_peer_gpatop obser_peer_gpamid obser_peer_gpabot control_peer_gpatop control_peer_gpamid control_peer_gpabot using endogenous_table_stacked_interacted.tex, nocons nonotes tex(frag pretty) replace se tdec(3) 10pct label cttop("Observational \& Control") addstat(F: Peer Effect for High Group: Observational v Control , `F1', p-value, `P1', F: Peer Effect for Low Group: Observational v Control , `F2', p-value, `P2')





* try running it with control being the incremental slope over and above the observational
xi: reg gpa peer_gpatop peer_gpamid peer_gpabot control_peer_gpatop control_peer_gpamid control_peer_gpabot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic control_peer_gpabot asian female gpa_bot gpa_top i.clsyr i.semester if treat!=1, robust cluster(class_sqd_yr)








**************************************************
* show whether the number of bottom peers matters in the observational control and treatment
**************************************************
* run for observations treat, control...run linear and nonlinear
xi: reg gpa peer_num_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)
outreg2 peer_num_bot using number_peers_bottom.tex, nocons nonotes replace se tdec(3) 10pct label cttop("Observational", "Group")

xi: reg gpa peer_num_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
outreg2 peer_num_bot using number_peers_bottom.tex, nocons nonotes append se tdec(3) 10pct label cttop("Control", "Group")


xi: reg gpa peer_num_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==1, robust cluster(class_sqd_yr)
outreg2 peer_num_bot using number_peers_bottom.tex, nocons nonotes tex(frag pretty) append se tdec(3) 10pct label cttop("Treatment", "Group")

* nonlinear version of same
xi: reg gpa peer_num_bottop  peer_num_botmid  peer_num_botbot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==., robust cluster(class_sqd_yr)
outreg2 peer_num_bottop  peer_num_botmid  peer_num_botbot using nonlin_number_peers_bottom.tex, nocons nonotes replace se tdec(3) 10pct label cttop("Observational", "Group")

xi: reg gpa peer_num_bottop  peer_num_botmid  peer_num_botbot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0, robust cluster(class_sqd_yr)
outreg2 peer_num_bottop  peer_num_botmid  peer_num_botbot using nonlin_number_peers_bottom.tex, nocons nonotes append se tdec(3) 10pct label cttop("Control", "Group")

xi: reg gpa peer_num_bottop  peer_num_botmid  peer_num_botbot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==1, robust cluster(class_sqd_yr)
outreg2 peer_num_bottop  peer_num_botmid  peer_num_botbot using nonlin_number_peers_bottom.tex, nocons nonotes tex(frag pretty) append se tdec(3) 10pct label cttop("Treatment", "Group")









**************************************************
* show that treatment status did give bottom students more high SAT verbal peers BUT also gave them more bottom peers and a higher percent in the bottom 25
* and the coefficients combine to add up to the negative treatment effect
**************************************************

xi: reg peer_satv75 treat_top treat_mid treat_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)
outreg2 treat_top treat_mid treat_bot using allocation_from_treatment.tex, nocons nonotes replace se tdec(3) 10pct label cttop("Fraction High SAT-V Peers")


xi: reg peer_satv25 treat_top treat_mid treat_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)
outreg2 treat_top treat_mid treat_bot using allocation_from_treatment.tex, nocons nonotes append se tdec(3) 10pct label cttop("Fraction Low SAT-V Peers")



xi: reg peer_num_bot treat_top treat_mid treat_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)
outreg2 treat_top treat_mid treat_bot using allocation_from_treatment.tex, nocons nonotes tex(frag pretty) append se tdec(3) 10pct label cttop("Number Peers of Low $\widehat{GPA}$")



**************************************************
* allow effect of treatment to vary by both my predicted GPA type AND my low or high SAT verbal
**************************************************


xi: reg peer_num_bot treat_top_highV treat_top_lowV treat_mid_highV treat_mid_lowV treat_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)


xi: reg peer_num_top treat_top_highV treat_top_lowV treat_mid_highV treat_mid_lowV treat_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)


xi: reg satv75_sum treat_top_highV treat_top_lowV treat_mid_highV treat_mid_lowV treat_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)



xi: reg satv25_sum treat_top_highV treat_top_lowV treat_mid_highV treat_mid_lowV treat_bot sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)

xi: reg gpa homogenous sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester, robust cluster(class_sqd_yr)



* summarize how the squadrons looked in the control and in the treatment


* do middle students do well in homogenous squadrons?

gen pct_mid=peer_num_mid/squad_size
gen pct_bot=peer_num_bot/squad_size
gen pct_top=peer_num_top/squad_size

gen homogenous2=pct_bot<.2 
gen homogenous3=pct_top<.2
gen homogenous4=pct_mid>.5

label var homogenous4 "Squadrons with $> 0.50$ Middle $\widehat{GPA} Students$"
label var homogenous3 "Squadrons with $< 0.20$ High $\widehat{GPA} Students$"
label var homogenous2 "Squadrons with $< 0.20$ Low $\widehat{GPA} Students$"



xi: reg gpa homogenous2 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & treat==. , robust cluster(class_sqd_yr)
sum homogenous2 if e(sample) & homogenous2==1
local numobs=r(N)
outreg2 homogenous2 using homogenous_in_observational.tex, nocons nonotes replace se 10pct bdec(3) tdec(3) label ctitle("Middle $\widehat{GPA}$", "Students", "GPA") addstat(Number Observations Who Meet This Definition of homogenous, `numobs')

xi: reg gpa homogenous3 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & treat==. , robust cluster(class_sqd_yr)
sum homogenous3 if e(sample) & homogenous3==1
local numobs=r(N)
outreg2 homogenous3 using homogenous_in_observational.tex, nocons nonotes append se 10pct bdec(3) tdec(3) label ctitle("Middle $\widehat{GPA}$", "Students", "GPA") addstat(Number Observations Who Meet This Definition of homogenous, `numobs')

xi: reg gpa homogenous4 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & treat==. , robust cluster(class_sqd_yr)
sum homogenous4 if e(sample) & homogenous4==1
local numobs=r(N)
outreg2 homogenous4 using homogenous_in_observational.tex, nocons nonotes tex(frag pretty) append se 10pct bdec(3) tdec(3) label ctitle("Middle $\widehat{GPA}$", "Students", "GPA") addstat(Number Observations Who Meet This Definition of homogenous, `numobs')






*******************************************************************
*** we need to calculate predicted treatment effects IF we used control group instead of observational group to make predictions
**********************************************************

*Estimate Predicted Treatment Effects Using Peer Effects Estimates in Control Group**

* start by running our baseline table 2 regression
xi: reg gpa peer_satvtop75 peer_satvmid75 peer_satvbot75 peer_satvtop25 peer_satvmid25 peer_satvbot25 sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if treat==0 /*, robust cluster(class_sqd_yr) */

* then predict into the treatment and control samples
predict gpa_hat3
predict gpa_hat_se2, stdf
gen gpa_hat_var2 = gpa_hat_se^2
egen treat_atype2 = group(treat gpa_top gpa_mid gpa_bot)
sort treat_atype2
by treat_atype2: egen m_gpa_hat_v2 = mean(gpa_hat_var2) 
by treat_atype2: egen group_count2 = count(gpa_hat_var2)
gen m_gpa_hat_var2 = m_gpa_hat_v2/group_count2


* get means and standard errors of prediction

reg gpa_hat3 treat control if treat!=. & semester==1 , nocons
ttest gpa_hat3 if e(sample) , by(treat)
local D1 = -r(t)*r(se)
sum m_gpa_hat_var2 if treat==1 
scalar t_var = r(mean)
display "Treatment SD =  " t_var^0.5
sum m_gpa_hat_var2 if treat==0 
scalar c_var = r(mean)
display "Control SD =  "c_var^0.5
local SE1 = (t_var+c_var)^0.5
outreg2 using prediction_using_control.tex, tdec(3) bdec(3) se label nonotes noaster replace addstat(Predicted Treatment Effect, `D1', SE of Predicted Difference, `SE1') ctitle("All", "Students") 



reg gpa_hat3 treat control if treat!=. & gpa_bot==1 & semester==1, nocons
ttest gpa_hat3 if e(sample) , by(treat)
local D1 = -r(t)*r(se)
sum m_gpa_hat_var2 if treat==1 & gpa_bot==1
scalar t_var = r(mean)
display "Treatment SD =  " t_var^0.5
sum m_gpa_hat_var2 if treat==0 & gpa_bot==1
scalar c_var = r(mean)
display "Control SD =  "c_var^0.5
local SE1 = (t_var+c_var)^0.5
outreg2 using prediction_using_control.tex, tdec(3) bdec(3)  se label noaster nonotes append addstat(Predicted Treatment Effect, `D1', SE of Predicted Difference, `SE1') ctitle("Bottom", "$\widehat{GPA}$") 


reg gpa_hat3 treat control if treat!=. & gpa_mid==1 & semester==1, nocons
ttest gpa_hat3 if e(sample) , by(treat)
local D1 = -r(t)*r(se)
sum m_gpa_hat_var2 if treat==1 & gpa_mid==1
scalar t_var = r(mean)
display "Treatment SD =  " t_var^0.5
sum m_gpa_hat_var2 if treat==0 & gpa_mid==1
scalar c_var = r(mean)
display "Control SD =  "c_var^0.5
local SE1 = (t_var+c_var)^0.5
outreg2 using prediction_using_control.tex, tdec(3)  bdec(3) se label noaster nonotes append addstat(Predicted Treatment Effect, `D1', SE of Predicted Difference, `SE1') ctitle("Middle", "$\widehat{GPA}$") 




reg gpa_hat3 treat control if treat!=. & gpa_top==1 & semester==1, nocons
ttest gpa_hat3 if e(sample) , by(treat)
local D1 = -r(t)*r(se)
sum m_gpa_hat_var2 if treat==1 & gpa_top==1
scalar t_var = r(mean)
display "Treatment SD =  " t_var^0.5
sum m_gpa_hat_var2 if treat==0 & gpa_top==1
scalar c_var = r(mean)
display "Control SD =  "c_var^0.5
local SE1 = (t_var+c_var)^0.5
outreg2 using prediction_using_control.tex, tex(frag pretty) tdec(3)  bdec(3) nonotes se label noaster append addstat(Predicted Treatment Effect, `D1', SE of Predicted Difference, `SE1') ctitle("Top", "$\widehat{GPA}$") 


*****************************************************************************
*****************************************************************************













**************************************************
* show histograms of how bifurcated the squadrons are
**************************************************


* new graphs for air force ppt
label var peer_num_bot "Number of Peers Below 25th Percentile of Predicted GPA"

twoway (hist peer_num_bot if gpa_bot==1 & treat==1, fraction color(red) ) (hist peer_num_bot if gpa_bot==1 & treat==., fraction color(blue)), legend(label( 1 treatment) label( 2 pre-treatment))

label var peer_satv75 "Percentage of Peers in Highest Quartile of SAT Verbal Distribution"
twoway (hist peer_satv75 if gpa_bot==1 & treat==1, color(red) fraction ) (hist peer_satv75 if gpa_bot==1 & treat==., fraction color(blue)), legend(label( 1 treatment) label( 2 pre-treatment))


* histogram for students in the bottom of predicted GPA



twoway (hist peer_num_bot if gpa_bot==1 & treat==1, color(red) ) (hist peer_num_bot if gpa_bot==1 & treat==., color(blue)), legend(label( 1 treatment) label( 2 pre-treatment)) ytitle("Density") ylabel(0(0.1)0.6) title("Peers Below 25th Percentile of Predicted GPA") subtitle("Bottom Third of Students")



twoway (hist peer_satv75 if gpa_bot==1 & treat==1, color(red) ) (hist peer_satv75 if gpa_bot==1 & treat==., color(blue)), legend(label( 1 treatment) label( 2 pre-treatment))

* histograms for students in middle of predicted gpa
twoway (hist peer_satv75 if gpa_mid==1 & treat==1, color(red) ) (hist peer_satv75 if gpa_mid==1 & treat==., color(blue)), legend(label( 1 treatment) label( 2 pre-treatment))

twoway (hist peer_num_bot if gpa_mid==1 & treat==1, color(red) ) (hist peer_num_bot if gpa_mid==1 & treat==., color(blue)), legend(label( 1 treatment) label( 2 pre-treatment)) ytitle("Density") ylabel(0(0.1)0.6) title("Peers Below 25th Percentile of Predicted GPA") subtitle("Middle Third of Students")

* Top predicted gpa

twoway (hist peer_num_bot if gpa_top==1 & treat==1, color(red) ) (hist peer_num_bot if gpa_top==1 & treat==., color(blue)), legend(label( 1 treatment) label( 2 pre-treatment)) ytitle("Density") ylabel(0(0.1)0.6) title("Peers Below 25th Percentile of Predicted GPA") subtitle("Top Third of Students") 

* histograms comparing number of bottom and top peers for bottom kids in the treatment group
twoway (hist peer_num_bot if gpa_bot==1 & treat==1, color(red) ) (hist peer_num_top if gpa_bot==1 & treat==1, color(green)), legend(label( 1 number bottom peers) label( 2 number top peers))

* run for observational group
twoway (hist peer_num_bot if gpa_bot==1 & treat==., color(red) ) (hist peer_num_top if gpa_bot==1 & treat==., color(green)), legend(label( 1 number bottom peers) label( 2 number top peers))

* run for control group
twoway (hist peer_num_bot if gpa_bot==1 & treat==0, color(red) ) (hist peer_num_top if gpa_bot==1 & treat==0, color(green)), legend(label( 1 number bottom peers) label( 2 number top peers))



****compare sample of students who responded to the survey****

xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_bot==1 & survey_num~=., robust cluster(class_sqd_yr)
xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_mid==1 & survey_num~=., robust cluster(class_sqd_yr)
xi: reg gpa treat sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr i.semester if gpa_top==1 & survey_num~=., robust cluster(class_sqd_yr)
gen respond=0
replace respond = 1 if survey_num~=. & clsyr>2010

reg respond treat sat_v sat_m aca_cmp leadership_cmp cft_score if semester==2


******************************************************************************************************************
*                                         Roommate Choices                                                       *
******************************************************************************************************************

use roommate2012.dta, clear

gen clsyr=2012
gen semester=1 if month>=8 & month<=12
replace semester=2 if month>=1 & month<=6

* rename number id
sort id semester

save roommate_prepped, replace



* create a roommate data set to merge in roommates scores, bot versus top standing and GPA

use air_force_combined_new, clear
* recreate gpa_hat

drop gpa_hat
xi:reg gpa sat_v sat_m leadership_cmp aca_cmp cft_score  rathlete pschool black hispanic asian female i.clsyr i.semester if treat==., robust cluster( class_sqd_yr_sem)  


predict gpa_hat 

keep if clsyr==2012

keep id semester gpa gpa_hat sat_v sat_m gpa_bot gpa_top gpa_mid satv75 satm75 satv25 satm25

sort id semester
gen gpa_lag=gpa[_n-1] if id==id[_n-1] & semester==2 & semester[_n-1]==1

foreach name in gpa gpa_hat gpa_lag sat_v sat_m gpa_bot gpa_top gpa_mid satv75 satm75 satv25 satm25 id {

rename `name' R1`name'

}

* get lagged gpa for second semester


*rename id roommate1
sort R1id semester
save R1_data_prepped, replace

* create the R2 data set

* rename roommate1 roommate2 


foreach name in gpa gpa_hat gpa_lag sat_v sat_m gpa_bot gpa_top gpa_mid satv75 satm75 satv25 satm25 id {

rename R1`name' R2`name'

}

sort R2id semester
save R2_data_prepped, replace






use air_force_combined_new, clear
drop gpa_hat
xi:reg gpa sat_v sat_m leadership_cmp aca_cmp cft_score  rathlete pschool black hispanic asian female i.clsyr i.semester if treat==., robust cluster( class_sqd_yr_sem)  



predict gpa_hat 

egen peer_gpa_hat=peers(gpa_hat), by(class_sqd_yr_sem)

egen peer_gpa_bot=peers(gpa_bot), by(class_sqd_yr_sem)

egen peer_gpa_top=peers(gpa_top), by(class_sqd_yr_sem)
keep if clsyr==2012

sort id semester


merge id semester using roommate_prepped

format id %12.0f

* merge in data on roommate1 and roommate2 for each semester
drop _m
sort R1id semester
merge R1id semester using R1_data_prepped

drop _m
sort R2id semester
merge R2id semester using R2_data_prepped

drop if id==.

sort id semester
gen gpa_lag=gpa[_n-1] if id==id[_n-1] & semester==2 & semester[_n-1]==1


* figure out if switched roommate
* I switched if I have a roommate 1 or 2 whom i did not have before
sort id semester
gen switch=0 if semester==2
replace switch=1 if id==id[_n-1] & (R1id!=R1id[_n-1] & R1id!=R2id[_n-1])  & R1id!=. & R1id[_n-1]!=.

replace switch=1 if id==id[_n-1] & (R2id!=R1id[_n-1] & R2id!=R2id[_n-1])  & R2id!=. 


* figure out whether roomate1 or roommate2 is new

sort id semester
gen newroommate1=0 if semester==2
replace newroommate1=1 if id==id[_n-1] & (R1id!=R1id[_n-1] & R1id!=R2id[_n-1])  & R1id!=. & R1id[_n-1]!=.

gen newroommate2=0 if semester==2
replace newroommate2=1 if id==id[_n-1] & (R2id!=R1id[_n-1] & R2id!=R2id[_n-1])  & R2id!=. 

egen class_sqd_year=group(squadron clsyr)
egen Rgpa_ave=rowmean(R1gpa R2gpa)
egen Rsatv75_ave = rowmean(R1satv75 R2satv75)

egen Rgpa_bot=rowmean(R1gpa_bot R2gpa_bot)
egen Rgpa_mid=rowmean(R1gpa_mid R2gpa_mid)
egen Rgpa_top=rowmean(R1gpa_top R2gpa_top)

egen Rgpa_lag=rowmean(R1gpa_lag R2gpa_lag)

egen Rgpa_hat=rowmean(R1gpa_hat R2gpa_hat)

egen Rsat_v=rowmean(R1sat_v R2sat_v)

egen Rsat_m=rowmean(R1sat_m R2sat_m)

label var gpa_lag "Semester 1 GPA"
label var Rgpa_lag "Roommate Semester 1 $\overline{GPA}$"
label var Rgpa_ave "Roommate $\overline{GPA}$"
label var Rgpa_bot "Roommate in Low $\widehat{GPA}$"



gen any_switch=0
replace any_switch=1 if newroommate1==1 | newroommate2==1

* ask if I am correlated with roommates background

reg sat_v R1sat_v if semester==1
reg sat_v R1sat_v if semester==2
reg sat_v R1sat_v if semester==2 & switch==1

reg gpa_bot R1gpa_bot if semester==1
reg gpa_bot R1gpa_bot if semester==2
reg gpa_bot R1gpa_bot if semester==2 & switch==1

reg sat_v Rsat_v if semester==1
reg sat_v Rsat_v if semester==2
reg sat_v Rsat_v if semester==2 & switch==1


reg gpa_bot Rgpa_bot if semester==1
reg gpa_bot Rgpa_bot if semester==2
reg gpa_bot Rgpa_bot if semester==2 & switch==1


gen newroommate_own_bottom=newroommate1*gpa_bot


*******************************************************************
* in the control group, there is no relation between my status in teh bottom and my roommates' status in the first semester
*******************************************************************

reg R1gpa_bot gpa_bot if semester==1 & treat==0

*******************************************************************
* this remains true in the second semester *******************************************************************

reg R1gpa_bot gpa_bot newroommate1 newroommate_own_bottom if semester==2 & treat==0


*******************************************************************
* in the treatment group, by construction I am more likely to have a bottom roommate if I am a bottom guy...you can see it doesn't hold within squadron
********************************************************************************
*******************************************************************
*  roommate groups don't realign in a way  that increases correlation with incoming scores...but they do realign to create correlation in lagged GPA

********************************************************************************


******************************************************
* switching doesn't really matter since not switching is a choice too
*******************************************************************

* reg gpa_bot Rgpa_bot if semester==1 & treat==1, cluster(class_sqd_year)

**********************************************************
* first table: no relation between my background or my GPA and my roommates' in first semester
*********************************************************************
* take own variables out of regression since selection may be occuring on background

xi: areg gpa_bot Rgpa_bot if semester==1 & treat==1 & peer_num_bot>2, absorb(squadron) cluster(class_sqd_year) 
outreg2 using first_semester_random, replace se bdec(3) tdec(3) word label cttop("Treatment Group") 10pct

xi: areg gpa_bot Rgpa_bot if semester==1 & treat==0, absorb(squadron) cluster(class_sqd_year)
outreg2 using first_semester_random, append se bdec(3) tdec(3) word label cttop("Control Group")  10pct 


xi: areg gpa Rgpa_ave if treat==1 & semester==1 & peer_num_bot>2, absorb(squadron) cluster(class_sqd_year)
outreg2 using first_semester_random, append se bdec(3) tdec(3) word label cttop("Treatment Group")  10pct 


xi: areg gpa Rgpa_ave if treat==0 & semester==1, absorb(squadron) cluster(class_sqd_year)
outreg2 using first_semester_random, append se bdec(3) tdec(3) word label cttop("Control Group")  10pct 


*******************************
* show that students sort into rooming groups for second semester
**********************************


xi: areg gpa_lag Rgpa_lag if treat==1 & semester==2 & peer_num_bot>2, absorb(squadron) cluster(class_sqd_year)
outreg2 using second_semester_nonrandom, replace se bdec(3) tdec(3) word label cttop("Treatment Group")   10pct 


xi: areg gpa_lag Rgpa_lag if treat==0 & semester==2, absorb(squadron) cluster(class_sqd_year)
outreg2 using second_semester_nonrandom, append se bdec(3) tdec(3) word label cttop("Control Group")  10pct 


xi: areg gpa Rgpa_ave if treat==1 & semester==2 & peer_num_bot>2, absorb(squadron) cluster(class_sqd_year)
outreg2 using second_semester_nonrandom, append se bdec(3) tdec(3) word label cttop("Treatment Group")  10pct 


xi: areg gpa Rgpa_ave if treat==0 & semester==2, absorb(squadron) cluster(class_sqd_year)
outreg2 using second_semester_nonrandom, append se bdec(3) tdec(3) word label cttop("Control Group")  10pct 


*******************************
* Alternate Models for Roommates*
**********************************
gen treat_top=treat*gpa_top
gen treat_mid=treat*gpa_mid
gen treat_bot=treat*gpa_bot

label var treat_top "Treatment Group $\times$ High $\widehat{GPA}$"
label var treat_mid "Treatment Group $\times$ Middle $\widehat{GPA}$"
label var treat_bot "Treatment Group $\times$ Low $\widehat{GPA}$"


xi: reg Rgpa_hat treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_fall.tex, nocons nonotes replace tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "$\widehat{GPA}$", "Fall Sem")

xi: reg Rgpa_bot treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_fall.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "Low $\widehat{GPA}$", "Fall Sem")


xi: reg Rgpa_mid treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_fall.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "Middle $\widehat{GPA}$", "Fall Sem")

xi: reg Rgpa_top treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_fall.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "High $\widehat{GPA}$", "Fall Sem")

xi: reg Rsatv75_ave treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_fall.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "High SAT-V", "Fall Sem")

xi: reg Rsat_m treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_fall.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "SAT Math", "Fall Sem")

xi: reg Rgpa_ave treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==1 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_fall.tex, nocons nonotes tex(frag pretty) append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "GPA", "Fall Sem")




xi: reg Rgpa_bot treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes replace tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "Low $\widehat{GPA}$", "Spring Sem")
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "Low $\widehat{GPA}$", "Spring Sem")


xi: reg Rgpa_mid treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "Middle $\widehat{GPA}$", "Spring Sem")
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "Middle $\widehat{GPA}$", "Spring Sem")

xi: reg Rgpa_top treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "High $\widehat{GPA}$", "Spring Sem")
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "High $\widehat{GPA}$", "Spring Sem")

xi: reg Rsatv75_ave treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "High SAT-V", "Spring Sem")
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "High SAT-V", "Spring Sem")

xi: reg Rgpa_hat treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2 , robust cluster(class_sqd_yr)
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "Mean $\widehat{GPA}$", "Spring Sem")
outreg2 treat_bot treat_mid treat_top using roommates_table_new_spr.tex, nocons nonotes tex(frag pretty) append tdec(3) bdec(3)  se 10pct label ctitle("Roommate", "Mean $\widehat{GPA}$", "Spring Sem")

sort clsyr id semester

save roommate_master_dataset, replace


**************************************
****** Study Partner Resample ********
**************************************



use  experiment_survey_merged

set seed 20120113
xi: reg fraction_study_low_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen partner = 0
keep if semester==2 & clsyr > 2010
gen partner_group = 0
tempname outfile
file open `outfile' using "Study_Partner_Resample_1.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace partner=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 2 groups of 6 study partners
   quietly replace partner = int((squad_rank-1)/6)+1
   * generate 1 group of 5 study partners
   quietly replace partner = int((squad_rank-3)/5)+1 if squad_rank > 12
   * generate 1 group of 4 study partners
   quietly replace partner = int((squad_rank-2)/4) if squad_rank > 17
   * generate 2 groups of 3 study partners
   quietly replace partner = int((squad_rank-1)/3)-2 if squad_rank > 21
   * generate 1 group of 2 study partners
   quietly replace partner = int(squad_rank/2)-7 if squad_rank > 27
   * remainder have no study partners
   quietly replace partner = . if squad_rank > 29
   drop partner_group fraction_study_low_gpa
   quietly egen partner_group = group(clsyr squadron partner)
   sort partner_group
   quietly by partner_group:  egen fraction_study_low_gpa = peers(gpa_bot)
   quietly xi: reg fraction_study_low_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)

   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using study_partner_Resample_1.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 


clear
use  experiment_survey_merged
xi: reg fraction_study_mid_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen partner = 0
keep if semester==2 & clsyr > 2010
gen partner_group = 0
file open `outfile' using "Study_Partner_Resample_2.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace partner=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 2 groups of 6 study partners
   quietly replace partner = int((squad_rank-1)/6)+1
   * generate 1 group of 5 study partners
   quietly replace partner = int((squad_rank-3)/5)+1 if squad_rank > 12
   * generate 1 group of 4 study partners
   quietly replace partner = int((squad_rank-2)/4) if squad_rank > 17
   * generate 2 groups of 3 study partners
   quietly replace partner = int((squad_rank-1)/3)-2 if squad_rank > 21
   * generate 1 group of 2 study partners
   quietly replace partner = int(squad_rank/2)-7 if squad_rank > 27
   * remainder have no study partners
   quietly replace partner = . if squad_rank > 29
   drop partner_group fraction_study_mid_gpa
   quietly egen partner_group = group(clsyr squadron partner)
   sort partner_group
   quietly by partner_group:  egen fraction_study_mid_gpa = peers(gpa_mid)
   quietly xi: reg fraction_study_mid_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)

   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using study_partner_Resample_2.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

clear
use  experiment_survey_merged
xi: reg fraction_study_high_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen partner = 0
keep if semester==2 & clsyr > 2010
gen partner_group = 0
file open `outfile' using "Study_Partner_Resample_3.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace partner=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 2 groups of 6 study partners
   quietly replace partner = int((squad_rank-1)/6)+1
   * generate 1 group of 5 study partners
   quietly replace partner = int((squad_rank-3)/5)+1 if squad_rank > 12
   * generate 1 group of 4 study partners
   quietly replace partner = int((squad_rank-2)/4) if squad_rank > 17
   * generate 2 groups of 3 study partners
   quietly replace partner = int((squad_rank-1)/3)-2 if squad_rank > 21
   * generate 1 group of 2 study partners
   quietly replace partner = int(squad_rank/2)-7 if squad_rank > 27
   * remainder have no study partners
   quietly replace partner = . if squad_rank > 29
   drop partner_group fraction_study_high_gpa
   quietly egen partner_group = group(clsyr squadron partner)
   sort partner_group
   quietly by partner_group:  egen fraction_study_high_gpa = peers(gpa_top)
   quietly xi: reg fraction_study_high_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)

   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using study_partner_Resample_3.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

clear
use  experiment_survey_merged
reg fraction_high_satv_study treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen partner = 0
keep if semester==2 & clsyr > 2010
gen partner_group = 0
file open `outfile' using "Study_Partner_Resample_4.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace partner=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 2 groups of 6 study partners
   quietly replace partner = int((squad_rank-1)/6)+1
   * generate 1 group of 5 study partners
   quietly replace partner = int((squad_rank-3)/5)+1 if squad_rank > 12
   * generate 1 group of 4 study partners
   quietly replace partner = int((squad_rank-2)/4) if squad_rank > 17
   * generate 2 groups of 3 study partners
   quietly replace partner = int((squad_rank-1)/3)-2 if squad_rank > 21
   * generate 1 group of 2 study partners
   quietly replace partner = int(squad_rank/2)-7 if squad_rank > 27
   * remainder have no study partners
   quietly replace partner = . if squad_rank > 29
   drop partner_group fraction_high_satv_study
   quietly egen partner_group = group(clsyr squadron partner)
   sort partner_group
   quietly by partner_group:  egen fraction_high_satv_study = peers(satv75)
   quietly xi: reg fraction_high_satv_study treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)

   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using study_partner_Resample_4.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

clear
use  experiment_survey_merged
xi: reg fraction_study_low_gpa_50 treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen partner = 0
keep if semester==2 & clsyr > 2010
gen partner_group = 0
file open `outfile' using "Study_Partner_Resample_5.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace partner=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 2 groups of 6 study partners
   quietly replace partner = int((squad_rank-1)/6)+1
   * generate 1 group of 5 study partners
   quietly replace partner = int((squad_rank-3)/5)+1 if squad_rank > 12
   * generate 1 group of 4 study partners
   quietly replace partner = int((squad_rank-2)/4) if squad_rank > 17
   * generate 2 groups of 3 study partners
   quietly replace partner = int((squad_rank-1)/3)-2 if squad_rank > 21
   * generate 1 group of 2 study partners
   quietly replace partner = int(squad_rank/2)-7 if squad_rank > 27
   * remainder have no study partners
   quietly replace partner = . if squad_rank > 29
   drop partner_group fraction_study_low_gpa 
   quietly egen partner_group = group(clsyr squadron partner)
   sort partner_group
   quietly by partner_group:  egen fraction_study_low_gpa = peers(gpa_bot)
   quietly replace fraction_study_low_gpa_50 = .
   quietly replace fraction_study_low_gpa_50 = 1 if fraction_study_low_gpa > 0.5
   quietly replace fraction_study_low_gpa_50 = 0 if fraction_study_low_gpa <= 0.5
   quietly xi: reg fraction_study_low_gpa_50 treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)
   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using study_partner_Resample_5.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 



****************************************
********** Friend Resample *************
****************************************




use  experiment_survey_merged, clear


xi: reg fraction_friends_low_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)

quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]

set seed 20120113
gen random = 0
gen friend = 0
keep if semester==2 & clsyr > 2010
gen friend_group = 0
tempname outfile
file open `outfile' using "Friend_Resample_1.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace friend=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 3 groups of 6 friends
   quietly replace friend = int((squad_rank-1)/6)+1
   * generate 1 group of 5 friends
   quietly replace friend = int((squad_rank+1)/5) if squad_rank > 18
   * generate 1 group of 4 friends
   quietly replace friend = int(squad_rank/4)-1 if squad_rank > 23
   * generate 2 groups of 3 friends
   quietly replace friend = int((squad_rank-1)/3)-3 if squad_rank > 27
   * generate 1 group of 2 friends
   quietly replace friend = int((squad_rank-1)/2)-8 if squad_rank > 30
   * remainder have no friends
   quietly replace friend = . if squad_rank > 32
   drop friend_group fraction_friends_low_gpa
   quietly egen friend_group = group(clsyr squadron friend)
   sort friend_group
   quietly by friend_group:  egen fraction_friends_low_gpa = peers(gpa_bot)
   quietly xi: reg fraction_friends_low_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)

   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Friend_Resample_1.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

clear
use  experiment_survey_merged
xi: reg fraction_friends_mid_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen friend = 0
keep if semester==2 & clsyr > 2010
gen friend_group = 0
file open `outfile' using "Friend_Resample_2.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace friend=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 3 groups of 6 friends
   quietly replace friend = int((squad_rank-1)/6)+1
   * generate 1 group of 5 friends
   quietly replace friend = int((squad_rank+1)/5) if squad_rank > 18
   * generate 1 group of 4 friends
   quietly replace friend = int(squad_rank/4)-1 if squad_rank > 23
   * generate 2 groups of 3 friends
   quietly replace friend = int((squad_rank-1)/3)-3 if squad_rank > 27
   * generate 1 group of 2 friends
   quietly replace friend = int((squad_rank-1)/2)-8 if squad_rank > 30
   * remainder have no friends
   quietly replace friend = . if squad_rank > 32
   drop friend_group fraction_friends_mid_gpa
   quietly egen friend_group = group(clsyr squadron friend)
   sort friend_group
   quietly by friend_group:  egen fraction_friends_mid_gpa = peers(gpa_mid)
   quietly xi: reg fraction_friends_mid_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)

   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Friend_Resample_2.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

clear
use  experiment_survey_merged
xi: reg fraction_friends_high_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen friend = 0
keep if semester==2 & clsyr > 2010
gen friend_group = 0
file open `outfile' using "Friend_Resample_3.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace friend=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 3 groups of 6 friends
   quietly replace friend = int((squad_rank-1)/6)+1
   * generate 1 group of 5 friends
   quietly replace friend = int((squad_rank+1)/5) if squad_rank > 18
   * generate 1 group of 4 friends
   quietly replace friend = int(squad_rank/4)-1 if squad_rank > 23
   * generate 2 groups of 3 friends
   quietly replace friend = int((squad_rank-1)/3)-3 if squad_rank > 27
   * generate 1 group of 2 friends
   quietly replace friend = int((squad_rank-1)/2)-8 if squad_rank > 30
   * remainder have no friends
   quietly replace friend = . if squad_rank > 32
   drop friend_group fraction_friends_high_gpa
   quietly egen friend_group = group(clsyr squadron friend)
   sort friend_group
   quietly by friend_group:  egen fraction_friends_high_gpa = peers(gpa_top)
   quietly xi: reg fraction_friends_high_gpa treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)

   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Friend_Resample_3.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

clear
use  experiment_survey_merged
xi: reg fraction_high_satv_friends treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen friend = 0
keep if semester==2 & clsyr > 2010
gen friend_group = 0
file open `outfile' using "Friend_Resample_4.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace friend=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 3 groups of 6 friends
   quietly replace friend = int((squad_rank-1)/6)+1
   * generate 1 group of 5 friends
   quietly replace friend = int((squad_rank+1)/5) if squad_rank > 18
   * generate 1 group of 4 friends
   quietly replace friend = int(squad_rank/4)-1 if squad_rank > 23
   * generate 2 groups of 3 friends
   quietly replace friend = int((squad_rank-1)/3)-3 if squad_rank > 27
   * generate 1 group of 2 friends
   quietly replace friend = int((squad_rank-1)/2)-8 if squad_rank > 30
   * remainder have no friends
   quietly replace friend = . if squad_rank > 32
   drop friend_group fraction_high_satv_friends
   quietly egen friend_group = group(clsyr squadron friend)
   sort friend_group
   quietly by friend_group:  egen fraction_high_satv_friends = peers(satv75)
   quietly xi: reg fraction_high_satv_friends treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)

   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Friend_Resample_4.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

clear
use  experiment_survey_merged
xi: reg fraction_friends_low_gpa_50 treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen friend = 0
keep if semester==2 & clsyr > 2010
gen friend_group = 0
file open `outfile' using "Friend_Resample_5.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace friend=.
   quietly replace random = runiform()
   sort clsyr squadron
   * Compute rank order of random draw within squadron 
   by clsyr squadron: egen squad_rank = rank(random)
   * generate 2 groups of 6 friends friends
   quietly replace friend = int((squad_rank-1)/6)+1
   * generate 1 group of 5 friends friends
   quietly replace friend = int((squad_rank-3)/5)+1 if squad_rank > 12
   * generate 1 group of 4 friends friends
   quietly replace friend = int((squad_rank-2)/4) if squad_rank > 17
   * generate 2 groups of 3 friends friends
   quietly replace friend = int((squad_rank-1)/3)-2 if squad_rank > 21
   * generate 1 group of 2 friends friends
   quietly replace friend = int(squad_rank/2)-7 if squad_rank > 27
   * remainder have no friends friends
   quietly replace friend = . if squad_rank > 29
   drop friend_group fraction_friends_low_gpa 
   quietly egen friend_group = group(clsyr squadron friend)
   sort friend_group
   quietly by friend_group:  egen fraction_friends_low_gpa = peers(gpa_bot)
   quietly replace fraction_friends_low_gpa_50 = .
   quietly replace fraction_friends_low_gpa_50 = 1 if fraction_friends_low_gpa > 0.5
   quietly replace fraction_friends_low_gpa_50 = 0 if fraction_friends_low_gpa <= 0.5
   quietly xi: reg fraction_friends_low_gpa_50 treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)
   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Friend_Resample_5.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 


***********************************************************************
*************** Roommate Resample *************************************
***********************************************************************


use  roommate_master_dataset, clear

set seed 20120112
xi:reg Rgpa_hat treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr  if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen roommate = 0
keep if semester==2 & clsyr > 2010
gen roommate_group = 0
tempname outfile
file open `outfile' using "Roommate_Resample_1.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace roommate=.
   quietly replace random = runiform()
   sort clsyr squadron female
   * Compute rank order of random draw within squadron by gender
   by clsyr squadron female: egen squad_rank = rank(random)
   quietly replace roommate = int((squad_rank-1)/3)+1
   * Each squadron has around 8 or 9 female members.  Create 2 triple rooms 
   * and place the remainder in double rooms
   quietly replace roommate = int((squad_rank-1)/2) if female == 1 & squad_rank > 6
   * 56% of male students are in triple rooms -> need 6 triple rooms and the rest double
   quietly replace roommate = int((squad_rank+1)/2)-3 if female == 0 & squad_rank > 18
   drop roommate_group
   quietly egen roommate_group = group(clsyr squadron female roommate)
   drop Rgpa_hat
   sort roommate_group
   quietly by roommate_group:  egen Rgpa_hat = peers(gpa_hat)
   quietly xi:reg Rgpa_hat treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr , robust cluster(class_sqd_yr)
   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Roommate_Resample_1.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

clear
use  roommate_master_dataset
reg Rgpa_bot treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen roommate = 0
keep if semester==2 & clsyr > 2010
gen roommate_group = 0
file open `outfile' using "Roommate_Resample_2.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace roommate=.
   quietly replace random = runiform()
   sort clsyr squadron female
   * Compute rank order of random draw within squadron by gender
   by clsyr squadron female: egen squad_rank = rank(random)
   quietly replace roommate = int((squad_rank-1)/3)+1
   * Each squadron has around 8 or 9 female members.  Create 2 triple rooms 
   * and place the remainder in double rooms
   quietly replace roommate = int((squad_rank-1)/2) if female == 1 & squad_rank > 6
   * 56% of male students are in triple rooms -> need 6 triple rooms and the rest double
   quietly replace roommate = int((squad_rank+1)/2)-3 if female == 0 & squad_rank > 18
   drop roommate_group
   quietly egen roommate_group = group(clsyr squadron female roommate)
   drop Rgpa_bot
   sort roommate_group
   quietly by roommate_group:  egen Rgpa_bot = peers(gpa_bot)
   quietly xi: reg Rgpa_bot treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)
   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Roommate_Resample_2.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 


clear
use  roommate_master_dataset
xi: reg Rgpa_mid treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen roommate = 0
keep if semester==2 & clsyr > 2010
gen roommate_group = 0
file open `outfile' using "Roommate_Resample_3.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace roommate=.
   quietly replace random = runiform()
   sort clsyr squadron female
   * Compute rank order of random draw within squadron by gender
   by clsyr squadron female: egen squad_rank = rank(random)
   quietly replace roommate = int((squad_rank-1)/3)+1
   * Each squadron has around 8 or 9 female members.  Create 2 triple rooms 
   * and place the remainder in double rooms
   quietly replace roommate = int((squad_rank-1)/2) if female == 1 & squad_rank > 6
   * 56% of male students are in triple rooms -> need 6 triple rooms and the rest double
   quietly replace roommate = int((squad_rank+1)/2)-3 if female == 0 & squad_rank > 18
   drop roommate_group
   quietly egen roommate_group = group(clsyr squadron female roommate)
   drop Rgpa_mid
   sort roommate_group
   quietly by roommate_group:  egen Rgpa_mid = peers(gpa_mid)
   quietly xi: reg Rgpa_mid treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)
   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Roommate_Resample_3.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 


clear
use  roommate_master_dataset
xi: reg Rgpa_top treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen roommate = 0
keep if semester==2 & clsyr > 2010
gen roommate_group = 0
file open `outfile' using "Roommate_Resample_4.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace roommate=.
   quietly replace random = runiform()
   sort clsyr squadron female
   * Compute rank order of random draw within squadron by gender
   by clsyr squadron female: egen squad_rank = rank(random)
   quietly replace roommate = int((squad_rank-1)/3)+1
   * Each squadron has around 8 or 9 female members.  Create 2 triple rooms 
   * and place the remainder in double rooms
   quietly replace roommate = int((squad_rank-1)/2) if female == 1 & squad_rank > 6
   * 56% of male students are in triple rooms -> need 6 triple rooms and the rest double
   quietly replace roommate = int((squad_rank+1)/2)-3 if female == 0 & squad_rank > 18
   drop roommate_group
   quietly egen roommate_group = group(clsyr squadron female roommate)
   drop Rgpa_top
   sort roommate_group
   quietly by roommate_group:  egen Rgpa_top = peers(gpa_top)
   quietly xi: reg Rgpa_top treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)
   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Roommate_Resample_4.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 


clear
use  roommate_master_dataset
xi: reg Rsatv75_ave treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr if semester==2, robust cluster(class_sqd_yr)
quietly scalar b_1 = _b[treat_bot]
quietly scalar b_2 = _b[treat_mid]
quietly scalar b_3 = _b[treat_top]
gen random = 0
gen roommate = 0
keep if semester==2 & clsyr > 2010
gen roommate_group = 0
file open `outfile' using "Roommate_Resample_5.csv", write text replace
file write `outfile' "beta_1, beta_2, beta_3" _n

forvalues i = 1(1)10000 {
   quietly replace roommate=.
   quietly replace random = runiform()
   sort clsyr squadron female
   * Compute rank order of random draw within squadron by gender
   by clsyr squadron female: egen squad_rank = rank(random)
   quietly replace roommate = int((squad_rank-1)/3)+1
   * Each squadron has around 8 or 9 female members.  Create 2 triple rooms 
   * and place the remainder in double rooms
   quietly replace roommate = int((squad_rank-1)/2) if female == 1 & squad_rank > 6
   * 56% of male students are in triple rooms -> need 6 triple rooms and the rest double
   quietly replace roommate = int((squad_rank+1)/2)-3 if female == 0 & squad_rank > 18
   drop roommate_group
   quietly egen roommate_group = group(clsyr squadron female roommate)
   drop Rsatv75_ave
   sort roommate_group
   quietly by roommate_group:  egen Rsatv75_ave = peers(satv75)
   quietly xi: reg Rsatv75_ave treat_bot treat_mid treat_top sat_v sat_m aca_cmp cft_score leadership_cmp rathlete pschool black  hispanic asian female gpa_bot gpa_top i.clsyr, robust cluster(class_sqd_yr)
   file write `outfile' (_b[treat_bot]) ", " (_b[treat_mid]) ", " (_b[treat_top])  _n
   drop squad_rank
   }
file close `outfile'
clear
insheet using Roommate_Resample_5.csv, comma
gen p_1 = b_1 < beta_1
gen p_2 = b_2 < beta_2
gen p_3 = b_3 < beta_3

sum 

log close

